_antonyms = {
    "способност": "неспособност",
    "абнормални": "нормално",
    "укинување": "утврди",
    "отсуство": "присуство",
    "отсутен": "присутен",
    "иднина": "минато",
    "апсолутно": "роднина",
    "апстинираат": "консумираат",
    "апстракт": "бетон",
    "изобилство": "ретки",
    "прифати": "отфрли",
    "признаам": "негира",
    "прифатливо": "неприфатливо",
    "прифаќање": "одбивање",
    "достапни": "недостапни",
    "точен": "неточни",
    "признати": "непознат",
    "познаник": "странец",
    "чин": "воздржете се",
    "акција": "неактивност",
    "активен": "тивок",
    "постоечки": "исчезнат",
    "бучна": "тивок",
    "активност": "неактивност",
    "вистински": "потенцијал",
    "додадете": "одземе",
    "покрај тоа": "одземање",
    "соодветен": "несоодветни",
    "придавка": "суштински",
    "допуштена": "неприфатливо",
    "возрасен": "малолетничка",
    "однапред": "отстапи",
    "напред": "заден",
    "вечер": "назад",
    "предност": "недостаток",
    "афирмација": "пресврт",
    "потврден": "негативно",
    "неутрален": "негативно",
    "назад": "напред",
    "возраст": "подмладување",
    "на возраст": "млад",
    "агитација": "смиреност",
    "се согласувам": "не се согласувам",
    "согласна": "непријатни",
    "договор": "проширен",
    "променети": "непроменета",
    "алтернативен": "спротивното",
    "аматер": "професионален",
    "двосмислена": "недвосмислено",
    "пријателски": "непријателски",
    "амфибиски": "земно",
    "анален": "орален",
    "аналогно": "хомологна",
    "анализа": "синтеза",
    "аналитички": "синтетички",
    "предок": "потомок",
    "аголна": "заоблени",
    "анимирај": "неживо",
    "одговор": "прашање",
    "антагонистички": "синергистички",
    "претходник": "последователните",
    "предна страна": "постериорно",
    "антисептик": "септички",
    "изглед": "исчезнување",
    "благодарност": "амортизација",
    "одобрување": "несогласување",
    "одобри": "одобри",
    "водни": "амфибиски",
    "земно": "небесен",
    "воден": "изненаден",
    "рака": "разоружа",
    "вооружени": "невооружени",
    "пристигне": "остави",
    "се искачи": "слезе",
    "искачување": "потекло",
    "спие": "буден",
    "асиметрија": "симетрија",
    "атеизам": "теизмот",
    "прикачи": "одвој",
    "напад": "брани",
    "гонење": "одбрана",
    "внимание": "невнимание",
    "атракција": "одбивност",
    "звучен": "нечујни",
    "зголемување": "декрет",
    "тетка": "чичко",
    "овластен": "неовластено",
    "автоматски": "прирачник",
    "избегнувајте": "се соочи",
    "буден": "спие",
    "отстапи": "однапред",
    "заден": "главата",
    "позадина": "преден план",
    "обратна": "аверс",
    "лошо": "добрина",
    "зло": "добро",
    "избалансиран": "неурамнотежен",
    "мечка": "бик",
    "убава": "грдо",
    "убавина": "грдотија",
    "започнете": "запре",
    "почеток": "средината",
    "рано": "доцна",
    "верување": "неверување",
    "се наведнуваат": "исправи",
    "бенигни": "малигни",
    "големо": "мал",
    "големи": "малолетник",
    "раѓање": "смрт",
    "бисексуалци": "хомосексуалец",
    "црна": "бела",
    "благослови": "проклетство",
    "благословен": "проколнати",
    "без крв": "крвав",
    "крвав": "без крв",
    "заматено": "фокус",
    "врие": "замрзнување",
    "задебелен": "срамежливи",
    "смелост": "плашливост",
    "позајми": "позајми",
    "заемопримачот": "давателот",
    "дното": "врв",
    "врзана": "неврзан",
    "момче": "девојче",
    "бојкот": "покрови",
    "пауза": "поправка",
    "кршливи": "нераскинлива",
    "осветли": "потемни",
    "скршен": "непрекинат",
    "брат": "сестра",
    "бик": "мечка",
    "зафатен": "неактивен",
    "работа": "неактивен",
    "купи": "продаде",
    "смирен": "горди",
    "смиреност": "агитација",
    "способен": "неспособни",
    "капацитет": "неспособност",
    "готовина": "кредит",
    "дебитна": "кредит",
    "центар": "лево",
    "церебрална": "емоционално",
    "сигурност": "неизвесност",
    "промена": "останете",
    "заминам": "останете",
    "се движи": "останете",
    "променлива": "непроменлив",
    "сменето": "непроменет",
    "задолжен": "празнење",
    "пријави": "празнење",
    "евтини": "скапо",
    "навиваат": "се жалат",
    "весели": "депресивно",
    "дете": "родител",
    "цивилен": "воена",
    "тврдат": "се губи",
    "јасност": "непроѕирност",
    "важност": "опскурност",
    "транспарентност": "непроѕирност",
    "чист": "нечист",
    "свештенството": "лаици",
    "свештеник": "лаик",
    "затвори": "отворен",
    "затворена": "отворен",
    "блискост": "отвореност",
    "крајбрежни": "во внатрешноста",
    "кохерентна": "некохерентни",
    "студ": "топло",
    "колатерал": "линеарен",
    "комедија": "трагедија",
    "удобност": "непријатност",
    "чести": "ретко",
    "компатибилен": "некомпатибилни",
    "компетентност": "некомпетентност",
    "компетентен": "неспособни",
    "конкуренција": "соработка",
    "се жалат": "навиваат",
    "комплетноста": "некомплетност",
    "комплексен": "едноставно",
    "соединение": "едноставно",
    "согласност": "пркосен",
    "комплицира": "поедноставување",
    "конкавна": "конвексен",
    "суета": "смирение",
    "гордост": "смирение",
    "концентрација": "дистрибуција",
    "концентрично": "ексцентричен",
    "концепција": "заблуда",
    "загрижени": "незаинтересиран",
    "бетон": "апстракт",
    "потврдено": "непотврдени",
    "се соочи": "избегнувајте",
    "конјунктивно": "дисјугентен",
    "поврзи се": "исклучете го",
    "поврзани": "неповрзани",
    "свест": "несвесност",
    "конзервативен": "либерален",
    "зачувување": "отпад",
    "внимателен": "безмислено",
    "конзистентност": "неконзистентност",
    "согласка": "самогласка",
    "упадливи": "незабележливо",
    "уставно": "неуставен",
    "консумираат": "апстинираат",
    "содржина": "незадоволство",
    "континуирано": "дисконтинуиран",
    "продолжување": "скрати",
    "продолжи": "прекинете",
    "континуитет": "дисконтинуитет",
    "контракција": "експанзија",
    "погодно": "незгодно",
    "конвенционален": "неконвенционален",
    "конвергираат": "разминуваат",
    "конвергенција": "дивергенција",
    "конвергентна": "дивергентни",
    "конвексен": "конкавна",
    "убеден": "неубедени",
    "кул": "топлина",
    "соработка": "конкуренција",
    "космополитски": "провинциски",
    "храброст": "кукавичлук",
    "покритие": "открие",
    "тајно": "отворена",
    "кукавичлук": "храброст",
    "кредит": "дебитна",
    "доверител": "должник",
    "критикуваат": "пофалба",
    "плаче": "се смееш",
    "лекува": "неизлечива",
    "проклетство": "благослови",
    "проколнати": "благословен",
    "криви": "директно",
    "сече": "несечени",
    "опасност": "безбедност",
    "опасно": "безбеден",
    "темно": "светлина",
    "потемни": "осветли",
    "темнина": "леснотија",
    "тежина": "леснотија",
    "ќерка": "син",
    "ден": "ноќ",
    "глуви": "слух",
    "смрт": "раѓање",
    "должник": "доверител",
    "пристојност": "неприлична",
    "пристоен": "непристојни",
    "листопадни": "зимзелени",
    "одлука": "неодлучноста",
    "одлучувачки": "неодлучен",
    "пад": "подобрување",
    "намалување": "зголемување",
    "намален": "се зголеми",
    "декрет": "зголемување",
    "пораз": "победа",
    "брани": "гонење",
    "обвинетиот": "тужителот",
    "одбрана": "гонење",
    "дефанзивен": "офанзива",
    "пркосен": "согласност",
    "дефицит": "олово",
    "дефинирани": "недефинирано",
    "дефлација": "инфлација",
    "одложување": "брзање",
    "се задржува": "брзање",
    "побарувачка": "снабдување",
    "негира": "доказ",
    "отфрли": "прифати",
    "зависен": "независна",
    "депозит": "се повлече",
    "амортизација": "благодарност",
    "депресивно": "весели",
    "слезе": "се искачи",
    "потомок": "предок",
    "потекло": "искачување",
    "описни": "пропишан",
    "пожелно": "непожелни",
    "очај": "надеж",
    "очајни": "надеж",
    "уништени": "зачувани",
    "одвој": "прикачи",
    "деволуција": "еволуција",
    "се разликуваат": "еднакви",
    "нееднаков": "еднакви",
    "разлика": "истосност",
    "тешко": "тендер",
    "непријатно": "пријатен",
    "тешкотии": "леснотија",
    "вредни": "безвредни",
    "разредување": "концентрација",
    "дистрибуција": "концентрација",
    "валкани": "чист",
    "нечист": "чист",
    "оневозможи": "овозможи",
    "недостаток": "изобилство",
    "не се согласувам": "се согласувам",
    "непријатни": "согласна",
    "несогласување": "одобрување",
    "исчезнување": "изглед",
    "неодобрување": "одобрување",
    "разоружа": "рака",
    "празнење": "пријави",
    "одрекувам": "тврдат",
    "се губи": "тврдат",
    "непријатност": "удобност",
    "исклучете го": "поврзи се",
    "незадоволство": "задоволство",
    "прекин": "продолжување",
    "прекинете": "продолжи",
    "дисконтинуитет": "континуитет",
    "дисконтинуиран": "континуирано",
    "обесхрабри": "поттикнете",
    "обесхрабрување": "охрабрување",
    "ослободување": "се вклучи",
    "нечесен": "искрен",
    "нечесност": "искреност",
    "срамно": "чест",
    "дезинфицира": "зарази",
    "се распадне": "интегрираат",
    "дисјугентен": "конјунктивно",
    "не им се допаѓаат": "вкус",
    "исфрли": "ложа",
    "непослушност": "послушност",
    "непослушен": "послушен",
    "непослушни": "послушај се",
    "нарушување": "со цел",
    "неуредно": "уреден",
    "неорганизирано": "организирано",
    "незадоволен": "задоволен",
    "дисквалификува": "се квалификува",
    "дискредитиран": "реномирани",
    "заблуда": "концепција",
    "непочитување": "почитувана",
    "лоша услуга": "сервис",
    "различен": "слично",
    "дисонанца": "хармонија",
    "одврати": "убеди",
    "дистална": "проксимална",
    "далечно": "затвори",
    "отворен": "затвори",
    "разликува": "не се разликува",
    "недоверба": "доверба",
    "дневни": "ноќен",
    "разминуваат": "конвергираат",
    "дивергенција": "конвергенција",
    "дивергентни": "конвергентна",
    "подели": "обедини",
    "посебно": "множете се",
    "поделени": "обединета",
    "делив": "неделив",
    "домашен": "странски",
    "мајчин": "странски",
    "доминантна": "подредени",
    "хибернација": "активен",
    "исчезнат": "постоечки",
    "неактивен": "работа",
    "пасивно": "активен",
    "тивок": "бучна",
    "двојно": "сингл",
    "повеќекратно": "сингл",
    "гулаб": "јастреб",
    "драматично": "лирски",
    "сува": "влажни",
    "кисело": "слатка",
    "поради": "непотребно",
    "досадна": "остри",
    "израмните": "остри",
    "умирање": "зародиш",
    "леснотија": "тежина",
    "лесно": "непријатно",
    "одлив": "плима",
    "ексцентричен": "концентрично",
    "образовани": "необразован",
    "ефикасен": "неефикасен",
    "ефикасност": "неефикасност",
    "излез": "внесете",
    "еластична": "нееластичен",
    "подобни": "неподобен",
    "емоционално": "церебрална",
    "емпириски": "теоретски",
    "празнина": "полнота",
    "празен": "целосна",
    "тенки": "се згусне",
    "овозможи": "оневозможи",
    "поттикнете": "обесхрабри",
    "охрабрување": "обесхрабрување",
    "крајот": "почеток",
    "завршувајќи": "почеток",
    "средината": "рано",
    "ендемични": "космополитски",
    "провинциски": "космополитски",
    "енергичен": "летаргичен",
    "enforce": "ослободен",
    "се вклучи": "ослободување",
    "уживајте": "страдаат",
    "внесете": "излез",
    "еднакви": "нееднаков",
    "еднаквост": "нееднаквост",
    "екваториски": "поларна",
    "правична": "нееднакво",
    "избришете": "рекорд",
    "утврди": "укинување",
    "паметен": "нерамномерно",
    "зимзелени": "листопадни",
    "еволуција": "деволуција",
    "исклучување": "инклузија",
    "ослободен": "enforce",
    "издишува": "дишам",
    "постои": "непостоечки",
    "прошири": "тесен",
    "проширен": "договор",
    "експанзија": "контракција",
    "се очекува": "неочекувано",
    "скапо": "евтини",
    "искусен": "неискусни",
    "извоз": "увоз",
    "изрази": "локален",
    "општо": "специфични",
    "национално": "меѓународни",
    "екстериер": "внатрешни работи",
    "надворешен": "внатрешна",
    "надворешно": "вродена",
    "изгаснат": "запалам",
    "вонредна": "обични",
    "неуспешно": "поминува",
    "трчање": "стои",
    "неуспех": "успех",
    "фер": "нефер",
    "верен": "неверен",
    "падне": "пораст",
    "во собата": "пораст",
    "погрешно": "непогрешлив",
    "паѓа": "расте",
    "лага": "стојат",
    "фалсификат": "вистина",
    "слава": "срам",
    "познат": "непознат",
    "фенси": "обичен",
    "масти": "тенки",
    "целосна": "празен",
    "дебели": "тенки",
    "се згусне": "тенки",
    "татко": "мајка",
    "фауна": "флора",
    "поволна": "неповолно",
    "федерални": "унитарна",
    "женски": "среден",
    "женственост": "машкост",
    "плодна": "стерилен",
    "верност": "неверство",
    "фигура": "земјата",
    "пополнете": "празен",
    "најдете": "изгуби",
    "заврши": "започнете",
    "запре": "започнете",
    "конечни": "бесконечно",
    "оган": "вработи",
    "флексија": "продолжување",
    "плови": "мијалник",
    "извор": "мијалник",
    "флора": "фауна",
    "фокус": "заматено",
    "непријател": "пријател",
    "пати": "се расплетува",
    "следи": "претходи",
    "успее": "претходи",
    "следбеник": "лидер",
    "глупост": "интелигенција",
    "глупаво": "мудар",
    "нога": "главата",
    "опашка": "главата",
    "забрани": "дозвола",
    "fore": "назад",
    "преден план": "позадина",
    "странски": "мајчин",
    "заборави": "се сеќавам",
    "простува": "непростлив",
    "формализам": "имитација",
    "среќа": "несреќен",
    "аверс": "обратна",
    "фаул": "фер",
    "нефер": "фер",
    "пронајден": "изгубени",
    "братски": "идентични",
    "замрзнување": "врие",
    "често": "ретко",
    "пријател": "непријател",
    "главата": "опашка",
    "полнота": "празнина",
    "функционален": "органски",
    "неоргански": "органски",
    "добивка": "загуба",
    "гасовити": "солидна",
    "шупливи": "солидна",
    "се соберат": "се шири",
    "генералност": "посебност",
    "дарежлив": "скржавиот",
    "девојче": "момче",
    "добро": "зло",
    "добрина": "лошо",
    "постепено": "одеднаш",
    "благодарни": "неблагодарна",
    "поголемо": "помалку",
    "зелена": "зрели",
    "бруто": "net",
    "земјата": "фигура",
    "вина": "невиност",
    "виновен": "невини",
    "среќно": "за жал",
    "среќен": "несреќни",
    "цврстина": "порозност",
    "гласност": "мекост",
    "острина": "мекост",
    "хармонија": "дисонанца",
    "омраза": "љубовен",
    "јастреб": "гулаб",
    "здрав": "нездраво",
    "слух": "глуви",
    "топлина": "кул",
    "небесен": "земно",
    "хетерогеност": "хомогеност",
    "крие": "шоу",
    "вработи": "оган",
    "удри": "госпоѓица",
    "свето": "профана",
    "хомогеност": "хетерогеност",
    "хомологна": "аналогно",
    "хомосексуалец": "бисексуалци",
    "искрен": "нечесен",
    "искреност": "нечесност",
    "чест": "срамно",
    "надеж": "очај",
    "надевајќи се": "безнадежен",
    "безнадежен": "надевајќи се",
    "хоризонтална": "вертикално",
    "непријателски": "пријателски",
    "топло": "студ",
    "смирение": "гордост",
    "гладни": "жеден",
    "идентични": "братски",
    "изненаден": "воден",
    "запалам": "изгаснат",
    "игнорирај": "забележи",
    "нелегално": "правен",
    "незаконитост": "законитост",
    "нечитлив": "читлив",
    "нелогично": "логично",
    "имитација": "формализам",
    "нематеријално": "материјал",
    "незрелост": "зрелост",
    "неизмеримо": "мерливи",
    "неморално": "морално",
    "неморал": "морал",
    "бесмртна": "смртен",
    "бесмртност": "смртност",
    "непроменлив": "променлива",
    "непристрасност": "пристрасност",
    "непрооден": "преоден",
    "нетрпеливост": "трпение",
    "нетрпелив": "трпелив",
    "незабележливо": "упадливи",
    "несовршеност": "совршенство",
    "непропустлив": "пропустливост",
    "недозволиво": "дозволената",
    "безлична": "лично",
    "неволја": "љубезен",
    "увоз": "извоз",
    "важно": "неважно",
    "неможност": "можност",
    "импотентен": "моќен",
    "неверојатно": "веројатно",
    "подобрени": "неоправдано",
    "подобрување": "пад",
    "неразумно": "разумно",
    "нечистотија": "чистота",
    "неспособност": "капацитет",
    "недостапни": "достапни",
    "неточни": "точен",
    "неактивност": "активност",
    "несоодветни": "соодветен",
    "неприфатливо": "прифатливо",
    "неживо": "анимирај",
    "невнимание": "внимание",
    "нечујни": "звучен",
    "неспособни": "компетентен",
    "наклонет": "хоризонтална",
    "вертикално": "хоризонтална",
    "инклузија": "исклучување",
    "некохерентни": "кохерентна",
    "некомпатибилни": "компатибилен",
    "некомпетентност": "компетентност",
    "некомплетност": "комплетноста",
    "невнимателен": "претпазливи",
    "неконзистентност": "конзистентност",
    "незгодно": "погодно",
    "се зголеми": "намален",
    "неизлечива": "лекува",
    "неприлична": "пристојност",
    "непристојни": "солени",
    "неодлучноста": "одлука",
    "неодлучен": "одлучувачки",
    "независна": "зависен",
    "не се разликува": "разликува",
    "неделив": "делив",
    "затворен": "отворено",
    "неефикасни": "ефикасен",
    "неефикасност": "ефикасност",
    "неефикасен": "ефикасен",
    "нееластичен": "еластична",
    "неподобен": "подобни",
    "нееднаквост": "еднаквост",
    "нееднакво": "правична",
    "неискусни": "искусен",
    "непогрешлив": "погрешно",
    "срам": "слава",
    "зарази": "дезинфицира",
    "инфериорен": "супериорен",
    "инфериорност": "супериорност",
    "неверство": "верност",
    "бесконечно": "конечни",
    "инфлација": "дефлација",
    "информирани": "неинформирани",
    "ретко": "често",
    "влез": "излез",
    "населени": "ненаселени",
    "дишам": "издишува",
    "неправда": "правда",
    "во внатрешноста": "крајбрежни",
    "невиност": "вина",
    "невини": "виновен",
    "едноставен": "штетен",
    "неоперативна": "оперативен",
    "лудо": "нормален",
    "лудило": "разумност",
    "несигурност": "безбедност",
    "безначајност": "значење",
    "незначителен": "значајно",
    "нерастворлив": "растворлив",
    "несолвентност": "солвентност",
    "несолвентен": "растворувач",
    "нестабилност": "стабилност",
    "инструментална": "вокал",
    "инсуфициенција": "доволност",
    "недоволно": "доволно",
    "интегрираат": "се распадне",
    "интеграција": "сегрегација",
    "интелигенција": "глупост",
    "разбирливо": "неразбирливо",
    "наменети": "ненамерно",
    "намерно": "ненамерно",
    "заинтересирани": "незаинтересирани",
    "интересно": "неинтересен",
    "внатрешни работи": "екстериер",
    "средно": "основно",
    "внатрешна": "надворешен",
    "внатрешно": "надворешно",
    "меѓународни": "национално",
    "локален": "општо",
    "нетолеранција": "толеранција",
    "нетолерантен": "толерантни",
    "неподнослива": "исполнет",
    "интрамурална": "надворешно",
    "вродена": "надворешно",
    "невидливост": "видливост",
    "невидлив": "видлив",
    "принудно": "доброволно",
    "ирационален": "рационално",
    "нередовно": "редовно",
    "неправилност": "регуларност",
    "неважно": "важно",
    "неодговорно": "одговорен",
    "непочтителен": "почитуван",
    "проблем": "потсетиме",
    "заеднички": "одделно",
    "радост": "тага",
    "весела": "тажен",
    "помлади": "сениор",
    "правда": "неправда",
    "малолетничка": "возрасен",
    "kern": "kern",
    "вид": "нељубезен",
    "цар": "кралица",
    "лаици": "свештенството",
    "доцна": "рано",
    "се смееш": "плаче",
    "законски": "незаконско",
    "лабави": "напната",
    "опуштено": "напната",
    "лаик": "свештеник",
    "олово": "дефицит",
    "лидер": "следбеник",
    "остави": "пристигне",
    "лево": "центар",
    "правен": "нелегално",
    "законитост": "незаконитост",
    "легализира": "одметник",
    "читлив": "нечитлив",
    "давателот": "заемопримачот",
    "помалку": "поголемо",
    "летаргичен": "енергичен",
    "ниво": "се подигне",
    "пониско": "се подигне",
    "либерален": "конзервативен",
    "принос": "стојат",
    "светлина": "темно",
    "вкус": "не им се допаѓаат",
    "ограничен": "неограничено",
    "линеарен": "колатерал",
    "течност": "гасовити",
    "солидна": "шупливи",
    "специфични": "општо",
    "локација": "студио",
    "заклучување": "отклучи",
    "ложа": "исфрли",
    "логично": "нелогично",
    "долго": "кратко",
    "висок": "кратко",
    "олабави": "вкочанети",
    "изгуби": "најдете",
    "загуба": "добивка",
    "изгубени": "пронајден",
    "љубовен": "омраза",
    "љубов": "омраза",
    "лирски": "драматично",
    "мнозинство": "малцинство",
    "направи": "пауза",
    "поправка": "пауза",
    "машки": "женски",
    "малигни": "бенигни",
    "прирачник": "автоматски",
    "обележан": "необележани",
    "оженет": "немажени",
    "среден": "женски",
    "машкост": "женственост",
    "маска": "демаскирам",
    "материјал": "нематеријално",
    "мајчина": "татковски",
    "зрелост": "незрелост",
    "максимум": "минимум",
    "мерливи": "неизмеримо",
    "ментален": "физички",
    "милостив": "безмилосно",
    "безмилосно": "милостив",
    "воена": "цивилен",
    "ум": "заборави",
    "се сеќавам": "заборави",
    "минимум": "максимум",
    "малолетник": "големи",
    "малцинство": "мнозинство",
    "госпоѓица": "удри",
    "моларен": "молекуларна",
    "молекуларна": "моларен",
    "морално": "неморално",
    "морал": "неморал",
    "смртен": "бесмртна",
    "смртност": "бесмртност",
    "мајка": "татко",
    "множете се": "посебно",
    "обедини": "подели",
    "mutable": "непроменлив",
    "nadir": "зенит",
    "тесен": "прошири",
    "зародиш": "умирање",
    "негативно": "неутрален",
    "несовесни": "вредни",
    "внук": "внука",
    "net": "бруто",
    "внука": "внук",
    "ноќ": "ден",
    "ноќен": "дневни",
    "номинална": "реално",
    "нереален": "реално",
    "непостоечки": "постои",
    "нормално": "коси",
    "забележи": "игнорирај",
    "штетен": "едноставен",
    "нумерички": "вербална",
    "послушност": "непослушност",
    "послушен": "непослушен",
    "послушај се": "непослушни",
    "цел": "субјективно",
    "задолжително": "изборен",
    "коси": "нормално",
    "опскурност": "важност",
    "непроѕирност": "транспарентност",
    "окупирана": "ненаселени",
    "прекршок": "одбрана",
    "офанзива": "дефанзивен",
    "официјален": "неофицијален",
    "отвореност": "блискост",
    "оперативен": "неоперативна",
    "наспроти": "неприфатен",
    "спротивното": "алтернативен",
    "оптимизам": "песимизам",
    "оптимист": "песимист",
    "изборен": "задолжително",
    "орален": "анален",
    "со цел": "нарушување",
    "уреден": "неуредно",
    "обични": "вонредна",
    "органски": "неоргански",
    "организирано": "неорганизирано",
    "православни": "необично",
    "отворено": "затворен",
    "одметник": "легализира",
    "преценете": "потценувајте",
    "надземни": "површина",
    "отворена": "тајно",
    "пакет": "отпакувај",
    "болно": "безболно",
    "безболно": "болно",
    "паралелно": "коси",
    "родител": "дете",
    "пристрасност": "непристрасност",
    "посебност": "генералност",
    "делумно": "целосно",
    "преоден": "непрооден",
    "поминува": "трчање",
    "стои": "трчање",
    "минато": "иднина",
    "присутен": "отсутен",
    "татковски": "мајчина",
    "трпение": "нетрпеливост",
    "трпелив": "нетрпелив",
    "покрови": "бојкот",
    "мир": "војна",
    "казна": "награда",
    "забележлива": "незабележливо",
    "совршенство": "несовршеност",
    "пропустливост": "непропустлив",
    "дозволената": "недозволиво",
    "попустлив": "превентивна",
    "дозвола": "забрани",
    "лично": "безлична",
    "убеди": "одврати",
    "песимизам": "оптимизам",
    "песимист": "оптимист",
    "физички": "ментален",
    "обичен": "фенси",
    "тужителот": "обвинетиот",
    "пријатен": "непријатно",
    "задоволен": "незадоволен",
    "множина": "еднина",
    "поларна": "екваториски",
    "љубезен": "неволја",
    "популарна": "непопуларен",
    "порозност": "цврстина",
    "можност": "неможност",
    "постериорно": "предна страна",
    "моќен": "немоќен",
    "потенцијал": "вистински",
    "сиромаштија": "богатство",
    "немоќен": "моќен",
    "пофалба": "критикуваат",
    "претходи": "успее",
    "претходна": "наследувајќи",
    "префикс": "суфикс",
    "подготовка": "резолуција",
    "подготвени": "неподготвени",
    "пропишан": "описни",
    "присуство": "отсуство",
    "зачувани": "уништени",
    "превентивна": "попустлив",
    "основно": "средно",
    "приватен": "јавноста",
    "приватно": "јавно",
    "веројатно": "неверојатно",
    "продуктивен": "непродуктивни",
    "профана": "свето",
    "професионален": "аматер",
    "напредок": "регрес",
    "прогресивно": "регресивно",
    "потенцијален": "ретроспектива",
    "заштитени": "незаштитени",
    "горди": "смирен",
    "доказ": "негира",
    "проксимална": "дистална",
    "блиска": "крајно",
    "разумно": "неразумно",
    "јавноста": "приватен",
    "јавно": "приватно",
    "објавен": "необјавени",
    "повлече": "притисни",
    "точност": "доцнење",
    "чистка": "рехабилитира",
    "чистота": "нечистотија",
    "притисни": "повлече",
    "се квалификува": "дисквалификува",
    "кралица": "цар",
    "прашање": "одговор",
    "сомнително": "несомнено",
    "брзо": "полека",
    "се подигне": "пониско",
    "рационално": "ирационален",
    "реално": "нереален",
    "реален": "нереално",
    "успокојувај": "се грижи",
    "потсетиме": "проблем",
    "рекорд": "избришете",
    "воздржете се": "чин",
    "одбие": "прифати",
    "регрес": "напредок",
    "регресивно": "прогресивно",
    "редовно": "нередовно",
    "регуларност": "неправилност",
    "регулирани": "нерегулиран",
    "рехабилитира": "чистка",
    "одбивање": "прифаќање",
    "подмладување": "возраст",
    "роднина": "апсолутно",
    "релевантни": "неважно",
    "сигурен": "несигурен",
    "религиозни": "секуларна",
    "одбивност": "атракција",
    "реномирани": "дискредитиран",
    "углед": "заблуда",
    "се спротивстави": "предавање",
    "резолуција": "подготовка",
    "почит": "непочитување",
    "почитувана": "непочитување",
    "одговорен": "неодговорно",
    "воздржани": "неограничен",
    "ограничено": "неограничен",
    "ретроспектива": "потенцијален",
    "почитуван": "непочтителен",
    "пресврт": "афирмација",
    "награда": "казна",
    "возење": "прошетка",
    "зрели": "зелена",
    "пораст": "во собата",
    "расте": "паѓа",
    "ротор": "статор",
    "грубост": "мазност",
    "круг": "квадрат",
    "заоблени": "аголна",
    "рурални": "урбани",
    "брзање": "се задржува",
    "за жал": "среќно",
    "тага": "радост",
    "несреќа": "среќа",
    "безбеден": "опасно",
    "безбедност": "несигурност",
    "истосност": "разлика",
    "нормален": "лудо",
    "разумност": "лудило",
    "задоволство": "незадоволство",
    "солени": "непристојни",
    "ретки": "изобилство",
    "научни": "ненаучно",
    "скрупулозно": "бескрупулозните",
    "секуларна": "религиозни",
    "сегрегација": "интеграција",
    "себични": "несебичен",
    "продаде": "купи",
    "сениор": "помлади",
    "одделно": "заеднички",
    "поделба": "унија",
    "септички": "антисептик",
    "сервис": "лоша услуга",
    "се населиле": "несмирен",
    "остри": "израмните",
    "кратко": "висок",
    "скрати": "продолжување",
    "викај": "шепот",
    "шоу": "крие",
    "се намалува": "се протега",
    "страна": "дното",
    "врв": "дното",
    "значење": "безначајност",
    "значајно": "незначителен",
    "слично": "различен",
    "едноставно": "соединение",
    "поедноставување": "комплицира",
    "сингл": "повеќекратно",
    "еднина": "множина",
    "мијалник": "извор",
    "сестра": "брат",
    "спиење": "разбуди",
    "полека": "брзо",
    "мал": "големи",
    "мазност": "грубост",
    "мекост": "острина",
    "растворлив": "нерастворлив",
    "солвентност": "несолвентност",
    "растворувач": "несолвентен",
    "син": "ќерка",
    "тажен": "весела",
    "зборува": "напишано",
    "непишано": "напишано",
    "спорадични": "континуирано",
    "се шири": "се соберат",
    "квадрат": "круг",
    "стабилност": "нестабилност",
    "стабилно": "нестабилен",
    "стојат": "принос",
    "статор": "ротор",
    "останете": "се движи",
    "стабилен": "нестабилен",
    "стрмен": "постепено",
    "одеднаш": "постепено",
    "стерилен": "плодна",
    "вкочанети": "олабави",
    "скржавиот": "дарежлив",
    "бурна": "смирен",
    "директно": "криви",
    "исправи": "се наведнуваат",
    "странец": "познаник",
    "сила": "слабост",
    "се протега": "се намалува",
    "силно": "слабо",
    "студио": "локација",
    "субјективно": "цел",
    "подредени": "доминантна",
    "последователните": "претходник",
    "суштински": "придавка",
    "одземе": "додадете",
    "одземање": "покрај тоа",
    "наследувајќи": "претходна",
    "успех": "неуспех",
    "успешна": "неуспешни",
    "подлегнува": "преживее",
    "страдаат": "уживајте",
    "доволност": "инсуфициенција",
    "доволно": "недоволно",
    "суфикс": "префикс",
    "изгрејсонце": "зајдисонце",
    "зајдисонце": "изгрејсонце",
    "супериорен": "инфериорен",
    "супериорност": "инфериорност",
    "снабдување": "побарувачка",
    "поддржан": "неподдржан",
    "површина": "надземни",
    "предавање": "се спротивстави",
    "преживее": "подлегнува",
    "слатко": "кисело",
    "влажни": "сува",
    "слатка": "кисело",
    "симетрија": "асиметрија",
    "симпатична": "несимпатичен",
    "синергистички": "антагонистички",
    "синтеза": "анализа",
    "синтетички": "аналитички",
    "доцнење": "точност",
    "вкусно": "без вкус",
    "вкусна": "без вкус",
    "без вкус": "вкусна",
    "тендер": "тешко",
    "напната": "опуштено",
    "терминал": "средно",
    "теизмот": "атеизам",
    "теоретски": "емпириски",
    "жеден": "гладни",
    "безмислено": "внимателен",
    "пестовен": "непотребно",
    "плима": "одлив",
    "вратоврска": "одврзете",
    "срамежливи": "задебелен",
    "плашливост": "смелост",
    "толеранција": "нетолеранција",
    "толерантни": "нетолерантен",
    "заби": "беззабани",
    "беззабани": "заби",
    "допре": "недопрени",
    "исполнет": "неподнослива",
    "трагедија": "комедија",
    "обучени": "необучен",
    "доверба": "недоверба",
    "вистина": "фалсификат",
    "грдотија": "убавина",
    "грдо": "убава",
    "крајно": "блиска",
    "непознат": "познат",
    "непроменета": "променети",
    "недвосмислена": "двосмислена",
    "невооружени": "вооружени",
    "неовластено": "овластен",
    "неурамнотежен": "избалансиран",
    "неверување": "верување",
    "неврзан": "врзана",
    "нераскинлива": "кршливи",
    "непрекинат": "скршен",
    "неизвесност": "сигурност",
    "непроменет": "сменето",
    "чичко": "тетка",
    "невообичаено": "чести",
    "незаинтересиран": "загрижени",
    "непотврдени": "потврдено",
    "неповрзан": "поврзани",
    "несвесност": "свест",
    "неуставен": "уставно",
    "неконвенционален": "конвенционален",
    "неубедени": "убеден",
    "открие": "покритие",
    "несечени": "сече",
    "недефинирано": "дефинирани",
    "потценувајте": "преценете",
    "непожелни": "пожелно",
    "непотребно": "пестовен",
    "необразован": "образовани",
    "недвосмислено": "двосмислена",
    "нерамномерно": "паметен",
    "неочекувано": "се очекува",
    "неверен": "верен",
    "неповолно": "поволна",
    "се расплетува": "пати",
    "непростлив": "простува",
    "несреќно": "среќа",
    "неблагодарна": "благодарни",
    "несреќни": "среќен",
    "нездраво": "здрав",
    "несреќен": "среќа",
    "неоправдано": "подобрени",
    "неинформирани": "информирани",
    "ненаселени": "окупирана",
    "неразбирливо": "разбирливо",
    "ненамерно": "намерно",
    "незаинтересирани": "заинтересирани",
    "неинтересен": "интересно",
    "унија": "поделба",
    "унитарна": "федерални",
    "обединета": "поделени",
    "нељубезен": "вид",
    "незаконско": "законски",
    "неограничено": "ограничен",
    "отклучи": "заклучување",
    "необележани": "обележан",
    "немажени": "оженет",
    "демаскирам": "маска",
    "неофицијален": "официјален",
    "неприфатен": "наспроти",
    "необично": "обично",
    "отпакувај": "пакет",
    "непопуларен": "популарна",
    "неподготвени": "подготвени",
    "непродуктивни": "продуктивен",
    "незаштитени": "заштитени",
    "необјавени": "објавен",
    "несомнено": "сомнително",
    "нереално": "реален",
    "нерегулиран": "регулирани",
    "неповрзани": "поврзани",
    "несигурен": "сигурен",
    "неограничен": "ограничено",
    "ненаучно": "научни",
    "бескрупулозните": "скрупулозно",
    "несебичен": "себични",
    "несмирен": "се населиле",
    "нестабилен": "стабилен",
    "неуспешни": "успешна",
    "неподдржан": "поддржан",
    "несимпатичен": "симпатична",
    "одврзете": "вратоврска",
    "недопрени": "допре",
    "необучен": "обучени",
    "открива": "превез",
    "неволно": "доброволно",
    "неподготвеност": "подготвеност",
    "развивам": "ветер",
    "недостоен": "достоен",
    "урбани": "рурални",
    "обично": "необично",
    "превез": "открива",
    "вербална": "нумерички",
    "победа": "пораз",
    "доблесни": "злите",
    "видливост": "невидливост",
    "видлив": "невидлив",
    "вокал": "инструментална",
    "доброволно": "неволно",
    "самогласка": "согласка",
    "разбуди": "спиење",
    "прошетка": "возење",
    "бледнее": "восок",
    "војна": "мир",
    "претпазливи": "невнимателен",
    "отпад": "зачувување",
    "восок": "бледнее",
    "слабо": "силно",
    "слабост": "сила",
    "богатство": "сиромаштија",
    "бестежински": "тешки",
    "тешки": "бестежински",
    "шепот": "викај",
    "бела": "црна",
    "целосно": "делумно",
    "злите": "доблесни",
    "широк": "тесен",
    "подготвеност": "неподготвеност",
    "ветер": "развивам",
    "мудрост": "глупост",
    "мудар": "глупаво",
    "се повлече": "депозит",
    "се грижи": "успокојувај",
    "безвредни": "вредни",
    "достоен": "недостоен",
    "напишано": "непишано",
    "млад": "на возраст",
    "зенит": "nadir",
}



_positive = set(
    [
        "abba",
        "capacità",
        "sopra citato",
        "assoluto",
        "assoluzione",
        "assorbito",
        "abbondante",
        "accademico",
        "accademia",
        "accettabile",
        "accettazione",
        "accessibile",
        "riconoscimento",
        "struttura ricettiva",
        "accompagnamento",
        "compiere",
        "compiuto",
        "realizzazione",
        "accordo",
        "responsabilità",
        "responsabile",
        "accreditato",
        "accueil",
        "preciso",
        "asso",
        "raggiungere",
        "risultato",
        "riconoscimento",
        "acquisire",
        "acquisire",
        "acrobata",
        "azione",
        "effettivo",
        "acutezza",
        "acume",
        "adattare",
        "adattabile",
        "indirizzi",
        "abile",
        "adeguatezza",
        "aggiunto",
        "ammirevole",
        "ammiraglio",
        "ammirazione",
        "ammirare",
        "ammiratore",
        "ammissibile",
        "adorabile",
        "adorazione",
        "adorare",
        "avanzare",
        "Avanzate",
        "avanzamento",
        "vantaggio",
        "vantaggioso",
        "Avvento",
        "avventura",
        "avventuroso",
        "consigliabile",
        "consigliare",
        "consigliere",
        "patrocinio",
        "estetico",
        "estetica",
        "affabile",
        "affetto",
        "affiliato",
        "affermare",
        "affermazione",
        "affermativa",
        "affermativamente",
        "ricchezza",
        "affluente",
        "permettersi",
        "aga",
        "agile",
        "agilità",
        "essere d'accordo",
        "piacevole",
        "concordato",
        "concordando",
        "accordo",
        "agricoltura",
        "avanti",
        "aiuto",
        "aiutare",
        "alabastro",
        "vigilanza",
        "alimentazione",
        "vivo",
        "placare",
        "fedeltà",
        "allegro",
        "alleviare",
        "Alleviazione",
        "alleato",
        "ammissibile",
        "fascino",
        "allettante",
        "alleato",
        "onnipotente",
        "aloha",
        "sorprendentemente",
        "ambasciatore",
        "ambizione",
        "migliorare",
        "amen",
        "suscettibile",
        "modificare",
        "ammenda",
        "amenità",
        "amabile",
        "amichevole",
        "amnistia",
        "amore",
        "divertire",
        "divertito",
        "divertimento",
        "divertente",
        "analista",
        "ancora",
        "ancoraggio",
        "angelo",
        "angelico",
        "animare",
        "animato",
        "antibiotici",
        "antidoto",
        "antimicotico",
        "antico",
        "antisettico",
        "aplomb",
        "scusarsi",
        "scusarsi",
        "scuse",
        "apostolo",
        "applausi",
        "apprezzamento",
        "approvazione",
        "approvazione",
        "approvare",
        "approvando",
        "azzeccato",
        "attitudine",
        "archeologia",
        "ardente",
        "ardore",
        "aristocrazia",
        "aristocratico",
        "armatura",
        "aroma",
        "suscitare",
        "Vettore",
        "arte",
        "articolare",
        "articolazione",
        "artigiano",
        "artista",
        "artistico",
        "ascendenza",
        "salita",
        "aspirazione",
        "aspirare",
        "aspirante",
        "assemblaggio",
        "assenso",
        "affermando",
        "risorse",
        "assistere",
        "assistenza",
        "socio",
        "placare",
        "assicurazione",
        "assicurato",
        "sorprendentemente",
        "stupore",
        "astrologo",
        "astronauta",
        "astronomo",
        "astuto",
        "atleta",
        "atletico",
        "atomo",
        "espiare",
        "espiazione",
        "attaccamento",
        "raggiungibile",
        "raggiungimento",
        "assistente",
        "Attenzione",
        "attento",
        "attestare",
        "avvocato",
        "attrazione",
        "attrattiva",
        "aumentare",
        "agosto",
        "zia",
        "aura",
        "di buon auspicio",
        "autentico",
        "autenticità",
        "autore",
        "autorevole",
        "autorità",
        "autorizzazione",
        "autorizzato",
        "avatar",
        "premio",
        "Ay",
        "si",
        "bambino",
        "diploma di maturità",
        "spina dorsale",
        "equilibrio",
        "equilibrato",
        "ballata",
        "balletto",
        "votazione",
        "balsamo",
        "banchetto",
        "battesimo",
        "battesimale",
        "bardo",
        "affare",
        "pallacanestro",
        "bastione",
        "bagno",
        "trave",
        "raggiante",
        "abbellimento",
        "Bellissima",
        "abbellire",
        "bellezza",
        "roccia di fondo",
        "birra",
        "adatto",
        "fare amicizia",
        "credendo",
        "benefattore",
        "benefico",
        "beneficio",
        "benevolenza",
        "benigno",
        "ormeggio",
        "promessa sposa",
        "miglioramento",
        "bevanda",
        "biblico",
        "bilingue",
        "nascita",
        "compleanno",
        "irreprensibile",
        "benedire",
        "benedetto",
        "benedizione",
        "benedizioni",
        "beatitudine",
        "beato",
        "senza sangue",
        "fioritura",
        "fiore",
        "guardia del corpo",
        "grassetto",
        "audacia",
        "sostenere",
        "bonanza",
        "bonne",
        "bonus",
        "libresco",
        "libreria",
        "vantaggio",
        "generoso",
        "generosità",
        "mazzo",
        "cervelli",
        "coraggio",
        "colazione",
        "nuziale",
        "sposa",
        "sposo",
        "damigella d'onore",
        "illuminare",
        "luminosità",
        "brillante",
        "broccato",
        "fratello",
        "fratellanza",
        "fraterno",
        "compagno",
        "costruire",
        "costruzione",
        "bulldog",
        "antiproiettile",
        "boa",
        "autobus",
        "maggiordomo",
        "burroso",
        "prosperoso",
        "ronzio",
        "taxi",
        "mobiletto",
        "bar",
        "calcolatrice",
        "vitello",
        "calma",
        "canarino",
        "Candido",
        "candidato",
        "candito",
        "capitalista",
        "Capitano",
        "affascinare",
        "accattivante",
        "carriera",
        "attento",
        "con attenzione",
        "carezza",
        "custode",
        "carlo",
        "cascata",
        "Contanti",
        "categorico",
        "provvedere",
        "catartico",
        "Cattedrale",
        "cauto",
        "con cautela",
        "celebre",
        "festeggiare",
        "celebrazione",
        "celeste",
        "centro",
        "centurione",
        "cerebrale",
        "cerimonia",
        "certezza",
        "presidente",
        "presidente",
        "campione",
        "canto",
        "caricabatterie",
        "caritatevole",
        "beneficenza",
        "fascino",
        "affascinante",
        "castità",
        "chiacchiere",
        "lista di controllo",
        "allegria",
        "allegro",
        "allegria",
        "tifo",
        "allegro",
        "chimico",
        "amare",
        "ciliegia",
        "capo",
        "bambino",
        "infanzia",
        "cinguettare",
        "scalpello",
        "cavalleria",
        "cioccolato",
        "scelta",
        "coro",
        "corale",
        "coro",
        "scelto",
        "zuppa",
        "cronaca",
        "ridacchiare",
        "Chiesa",
        "Cedro",
        "circoncisione",
        "cittadino",
        "civile",
        "civiltà",
        "civiltà",
        "civile",
        "chiaroveggente",
        "applaudire",
        "chiarire",
        "classico",
        "classico",
        "classici",
        "classificare",
        "pulire",
        "pulizia",
        "pulizia",
        "pulito",
        "pulire",
        "pulizia",
        "liquidazione",
        "chiarezza",
        "clericale",
        "intelligente",
        "intelligenza",
        "climax",
        "vicinanza",
        "chiusura",
        "vestire",
        "clown",
        "coalizione",
        "costa",
        "coesistere",
        "convincente",
        "cognitivo",
        "coerenza",
        "coerente",
        "coesivo",
        "collettivamente",
        "colonnello",
        "colossale",
        "comfort",
        "comandante",
        "comandare",
        "commemorare",
        "commemorazione",
        "commemorativo",
        "lodare",
        "lodevole",
        "commentatore",
        "impegnato",
        "commodoro",
        "Commonwealth",
        "comunicare",
        "comunicativo",
        "comunione",
        "Comunità",
        "commutazione",
        "tragitto casa-lavoro",
        "compagno",
        "compassione",
        "compassionevole",
        "Compatibilità",
        "compatibile",
        "avvincente",
        "compensare",
        "compensativo",
        "competenza",
        "competenza",
        "competente",
        "compiacimento",
        "complemento",
        "complementare",
        "completamente",
        "completezza",
        "completare",
        "completamento",
        "conformità",
        "conforme",
        "complimento",
        "composto",
        "compositore",
        "compostezza",
        "comprendere",
        "completo",
        "compagno",
        "concentrico",
        "conciliazione",
        "concludendo",
        "concordia",
        "concordanza",
        "condoglianze",
        "condonare",
        "favorevole",
        "conducibilità",
        "confederato",
        "fiducia",
        "fiducioso",
        "confermato",
        "conformità",
        "congeniale",
        "congratulazioni",
        "congregazione",
        "congruenza",
        "intenditore",
        "coscienza",
        "coscienzioso",
        "coscienza",
        "consacrazione",
        "conservazione",
        "conservare",
        "considerevole",
        "premuroso",
        "consistenza",
        "consolle",
        "consonante",
        "costanza",
        "costante",
        "costituzionale",
        "costruire",
        "consumato",
        "contatto",
        "contemplazione",
        "contenuto",
        "Continua",
        "contorno",
        "contribuire",
        "collaboratore",
        "convenienza",
        "conveniente",
        "convento",
        "convenzione",
        "conversatore",
        "colloquiale",
        "convertire",
        "convincere",
        "freddo",
        "freschezza",
        "cooperare",
        "cooperare",
        "cooperazione",
        "cooperativa",
        "nucleo",
        "incoronazione",
        "società",
        "corporeo",
        "correttivo",
        "corrispondenza",
        "corroborare",
        "Cosmopolita",
        "accogliente",
        "consiglio",
        "consiglio",
        "consulente",
        "contare",
        "contessa",
        "coraggio",
        "coraggioso",
        "Cortese",
        "cortesia",
        "corteggiamento",
        "baia",
        "patto",
        "culla",
        "mestiere",
        "artigiano",
        "crema",
        "creare",
        "creativo",
        "credito",
        "credenziali",
        "credibilità",
        "credibile",
        "credito",
        "credibile",
        "accreditato",
        "crescendo",
        "critica",
        "coronamento",
        "cruciale",
        "cristallo",
        "abbraccio",
        "culinario",
        "culmine",
        "coltivare",
        "coltivato",
        "coltivazione",
        "cultura",
        "curabile",
        "curiosità",
        "arricciare",
        "cuscino",
        "cliente",
        "carino",
        "taglierine",
        "signora",
        "danza",
        "audace",
        "tesoro",
        "focoso",
        "figlia",
        "alba",
        "affare",
        "caro",
        "discussione",
        "decenza",
        "decente",
        "dichiarativo",
        "dedizione",
        "difendere",
        "difeso",
        "difensore",
        "difendere",
        "difesa",
        "deferenza",
        "definitivo",
        "livello",
        "delizioso",
        "delegare",
        "deliberato",
        "delizioso",
        "delizia",
        "incantato",
        "delizioso",
        "liberazione",
        "consegna",
        "democrazia",
        "dimostrabile",
        "dimostrativo",
        "profondità",
        "descrittivo",
        "meritare",
        "meritato",
        "progettista",
        "auspicabile",
        "desiderando",
        "desideroso",
        "destinazione",
        "rilevare",
        "rilevamento",
        "determinazione",
        "determinato",
        "sviluppare",
        "devozionale",
        "devoto",
        "destrezza",
        "diamante",
        "diario",
        "dizionario",
        "didattico",
        "dietetico",
        "dignitoso",
        "dignità",
        "diligenza",
        "cena",
        "diplomazia",
        "diplomatico",
        "direttore",
        "scoperta",
        "discreto",
        "riservatezza",
        "discrezionale",
        "discussione",
        "disinfezione",
        "disposto",
        "diffondere",
        "distillazione",
        "distinzione",
        "canzoncina",
        "diversificato",
        "diversione",
        "divinità",
        "medico",
        "agente",
        "ostinato",
        "delfino",
        "assistente",
        "donazione",
        "senza dubbio",
        "colomba",
        "lanuginoso",
        "duetto",
        "duca",
        "durabilità",
        "durevole",
        "doveroso",
        "desideroso",
        "impazienza",
        "conte",
        "guadagnare",
        "serio",
        "seriamente",
        "serietà",
        "sollievo",
        "servitù",
        "di buon carattere",
        "mangiare",
        "estasi",
        "estatico",
        "edificazione",
        "educare",
        "educato",
        "educativo",
        "efficace",
        "efficacia",
        "efficienza",
        "efficiente",
        "sforzo",
        "eiaculazione",
        "elaborazione",
        "euforico",
        "Sambuco",
        "anziani",
        "eleggere",
        "elettrico",
        "elettricità",
        "eleganza",
        "elegante",
        "elevazione",
        "ammissibile",
        "elite",
        "eloquenza",
        "eloquente",
        "chiarire",
        "emancipazione",
        "abbraccio",
        "emerito",
        "eminenza",
        "eminente",
        "eminentemente",
        "emiro",
        "empatia",
        "potenziare",
        "emulare",
        "abilitare",
        "abilitazione",
        "incantare",
        "incantato",
        "incantevole",
        "bis",
        "incoraggiare",
        "incoraggiamento",
        "enciclopedia",
        "tentativo",
        "dotare",
        "dotato",
        "dotazione",
        "resistenza",
        "sopportare",
        "energico",
        "impegnato",
        "coinvolgente",
        "migliorare",
        "divertiti",
        "godendo",
        "illuminare",
        "illuminazione",
        "ravvivare",
        "arricchire",
        "insieme",
        "guardiamarina",
        "intraprendente",
        "intrattenere",
        "intrattenuto",
        "divertente",
        "intrattenimento",
        "entusiasmo",
        "appassionato",
        "ambiente",
        "effemeridi",
        "epico",
        "epitome",
        "uguaglianza",
        "ugualmente",
        "equilibrio",
        "equità",
        "commissione",
        "erudito",
        "spirito",
        "essenziale",
        "stabilito",
        "stima",
        "estetico",
        "etico",
        "etica",
        "sempreverde",
        "eterno",
        "evidente",
        "Evoluzione",
        "esaltare",
        "esaltazione",
        "esaltato",
        "superare",
        "eccellere",
        "eccellenza",
        "eccellente",
        "scambio",
        "eccitabile",
        "eccitazione",
        "eccitare",
        "emozionato",
        "eccitazione",
        "eccitante",
        "esemplare",
        "esenzione",
        "euforia",
        "esortare",
        "esortazione",
        "esistenza",
        "esotico",
        "aspettare",
        "aspettativa",
        "espediente",
        "spedizione",
        "esperto",
        "esperto",
        "competenza",
        "spiegare",
        "squisito",
        "squisitamente",
        "estendere",
        "ampio",
        "extra",
        "straordinario",
        "districarsi",
        "esuberanza",
        "facilitare",
        "fatti",
        "facoltà",
        "debole",
        "giusto",
        "abbastanza",
        "fede",
        "fedele",
        "fama",
        "familiare",
        "familiarità",
        "famoso",
        "notoriamente",
        "fantasia",
        "fanfara",
        "affascinante",
        "fascino",
        "alla moda",
        "impeccabile",
        "favorevole",
        "preferito",
        "favoritismo",
        "senza paura",
        "impresa",
        "caratteristica",
        "felicità",
        "compagno",
        "compagnia",
        "femmina",
        "fertile",
        "fervore",
        "Festival",
        "festivo",
        "festa",
        "fedeltà",
        "festa",
        "finalmente",
        "fronzoli",
        "finezza",
        "bolide",
        "ignifugo",
        "fermezza",
        "primogenito",
        "raccordo",
        "apparecchio",
        "lusinghiero",
        "flotta",
        "flessibilità",
        "floreale",
        "fluire",
        "fiorito",
        "sciacquone",
        "volare",
        "messa a fuoco",
        "affetto",
        "cibo",
        "calcio",
        "tolleranza",
        "prua, testa",
        "antenati",
        "precedente",
        "caposquadra",
        "precursore",
        "prevedere",
        "previsto",
        "lungimiranza",
        "fucina",
        "perdonare",
        "perdonato",
        "perdonare",
        "formativo",
        "formula",
        "forte",
        "prossimo",
        "fortificare",
        "forza d'animo",
        "fortezza",
        "fortunato",
        "fortuna",
        "inoltrare",
        "fondare",
        "fondazione",
        "fragrante",
        "Franco",
        "franchezza",
        "fraterno",
        "libertà",
        "liberamente",
        "amico",
        "cordialità",
        "amichevole",
        "amicizia",
        "vivace",
        "scherzare",
        "frugale",
        "fruttuoso",
        "esaudire",
        "compimento",
        "completo",
        "completamente",
        "divertimento",
        "fondamentale",
        "fusibile",
        "fusione",
        "guadagno",
        "guadagnando",
        "galante",
        "galanteria",
        "a bizzeffe",
        "giardino",
        "granato",
        "guarnigione",
        "gazzetta",
        "Ingranaggio",
        "gemma",
        "generale",
        "generosità",
        "generoso",
        "geniale",
        "genio",
        "signorile",
        "signore",
        "dolcezza",
        "nobiltà",
        "genuino",
        "geranio",
        "regalo",
        "dotato",
        "gigantesco",
        "ridacchiare",
        "trave",
        "dando",
        "lieto",
        "letizia",
        "gioia",
        "scivolare",
        "barlume",
        "scintillante",
        "glorificazione",
        "glorificare",
        "gloria",
        "lucentezza",
        "incandescenza",
        "incandescente",
        "Dio",
        "divino",
        "manna dal cielo",
        "oro",
        "Buona",
        "bene",
        "bontà",
        "merce",
        "buona volontà",
        "bellissima",
        "vangelo",
        "governare",
        "adornare",
        "grazioso",
        "gentile",
        "graziosamente",
        "la laurea",
        "nipoti",
        "grandezza",
        "nonna",
        "concedere",
        "concesso",
        "grato",
        "gratificare",
        "gratitudine",
        "maggiore",
        "grandezza",
        "verde",
        "saluto",
        "gregario",
        "largo sorriso",
        "macinare",
        "grinta",
        "basi",
        "crescere",
        "crescita",
        "garanzia",
        "guardia",
        "custode",
        "tutela",
        "governativo",
        "guida",
        "guida",
        "guida",
        "guru",
        "intestini",
        "ginnasta",
        "habitat",
        "hale",
        "maneggevole",
        "felicemente",
        "felicità",
        "felice",
        "resistente",
        "armoniosamente",
        "armonia",
        "raccolto",
        "porto",
        "progresso",
        "guarire",
        "guarigione",
        "salutare",
        "sano",
        "sentito",
        "focolare",
        "di cuore",
        "celeste",
        "cieli",
        "peso",
        "casco",
        "aiutante",
        "utile",
        "base di erbe",
        "eroe",
        "eroico",
        "eroicità",
        "eroina",
        "eroismo",
        "periodo d'oro",
        "divertente",
        "ilarità",
        "assumere",
        "passatempo",
        "vacanza",
        "santità",
        "santo",
        "omaggio",
        "omologia",
        "onesto",
        "onestà",
        "Miele",
        "luna di miele",
        "onore",
        "onorevole",
        "speranza",
        "speranzoso",
        "orizzonte",
        "ospitalità",
        "domestico",
        "faccende domestiche",
        "abbraccio",
        "umano",
        "umanitario",
        "umanità",
        "onorato",
        "umilmente",
        "umiltà",
        "umorista",
        "umoristico",
        "evviva",
        "allevamento",
        "silenzio",
        "capanna",
        "igienico",
        "inno",
        "idealismo",
        "idolo",
        "illuminare",
        "illuminazione",
        "illustrare",
        "illustre",
        "fantasioso",
        "immacolato",
        "immenso",
        "immergere",
        "immortale",
        "impartire",
        "imparziale",
        "imparzialità",
        "impeccabile",
        "impervio",
        "importanza",
        "importante",
        "impressionare",
        "impressione",
        "Ottimizzare",
        "migliorato",
        "miglioramento",
        "migliorando",
        "improvvisare",
        "inalienabile",
        "inaugurazione",
        "incisivo",
        "includere",
        "incluso",
        "Compreso",
        "compreso",
        "aumento",
        "indelebile",
        "indennità",
        "indipendenza",
        "indistruttibile",
        "individualità",
        "indomabile",
        "ineffabile",
        "poco costoso",
        "infallibile",
        "infante",
        "infinito",
        "infinito",
        "influente",
        "informazione",
        "ingegnoso",
        "eredità",
        "inimitabile",
        "innocenza",
        "innocente",
        "innocentemente",
        "innocuo",
        "innovare",
        "innovazione",
        "ricercatore",
        "inchiesta",
        "curioso",
        "inseparabile",
        "insegne",
        "ispettore",
        "ispirazione",
        "ispirare",
        "ispirato",
        "istintivo",
        "istruire",
        "istruzione",
        "istruttore",
        "strumentale",
        "assicurare",
        "intatto",
        "integrità",
        "intelletto",
        "intellettuale",
        "intelligenza",
        "intelligente",
        "previsto",
        "rapporto",
        "interesse",
        "interessato",
        "interessante",
        "interno",
        "interlocutorio",
        "interludio",
        "intimo",
        "intonazione",
        "intrepido",
        "intuizione",
        "intuitivo",
        "invariabilmente",
        "fantasioso",
        "inventore",
        "indagare",
        "rinvigorire",
        "invito",
        "invitare",
        "invitante",
        "ferro da stiro",
        "irriducibile",
        "inconfutabile",
        "montepremi",
        "marmellata",
        "scherzo",
        "lavoro",
        "giuntura",
        "partecipato",
        "burlone",
        "scherzando",
        "giornalista",
        "viaggio",
        "gioviale",
        "la gioia",
        "gioioso",
        "gioioso",
        "giubilante",
        "giubileo",
        "giudiziario",
        "giudizioso",
        "salto",
        "giustizia",
        "giustificabile",
        "giustificazione",
        "ricordo",
        "ken",
        "nota chiave",
        "chiave di volta",
        "tipo",
        "gentilezza",
        "affine",
        "re",
        "bacio",
        "gattino",
        "abilità",
        "cavaliere",
        "sapendo",
        "conoscenza",
        "complimenti",
        "lavoro duro e faticoso",
        "agnello",
        "terra",
        "atterrato",
        "laser",
        "lodevole",
        "ridere",
        "ridendo",
        "risata",
        "lancio",
        "laureato",
        "alloro",
        "allori",
        "sontuoso",
        "lecito",
        "piombo",
        "capo",
        "lega",
        "imparare",
        "apprendimento",
        "docente",
        "margine di manovra",
        "legale",
        "legalizzato",
        "leggendario",
        "leggibilità",
        "leggibile",
        "tempo libero",
        "tranquillamente",
        "lemma",
        "indulgente",
        "lezione",
        "con lettere",
        "livello",
        "leva",
        "liberare",
        "liberazione",
        "libertà",
        "biblioteca",
        "linfa vitale",
        "faro",
        "gradimento",
        "linguista",
        "Leone",
        "agile",
        "logico",
        "longevità",
        "signoria",
        "amabile",
        "amore",
        "bello",
        "fare l'amore",
        "amante",
        "amorevole",
        "leale",
        "lealtà",
        "fortuna",
        "fortunato",
        "delizioso",
        "lustro",
        "brillante",
        "lussureggiante",
        "lussuoso",
        "lusso",
        "lira",
        "lirico",
        "magico",
        "magnete",
        "magnetismo",
        "magnetite",
        "magnificenza",
        "magnifico",
        "fanciulla",
        "principale",
        "pilastro",
        "maestoso",
        "maestà",
        "principale",
        "maggioranza",
        "gestire",
        "gestione",
        "mandarino",
        "virilità",
        "manifestato",
        "virile",
        "manna",
        "educato",
        "maniere",
        "produttore",
        "marzo",
        "segnato",
        "commerciabile",
        "marchese",
        "matrimonio",
        "midollo",
        "sposare",
        "maresciallo",
        "meraviglia",
        "meravigliosa",
        "meravigliosamente",
        "maschile",
        "massaggio",
        "maestro",
        "capolavoro",
        "padronanza",
        "compagno",
        "matrimonio",
        "matrona",
        "massimo",
        "Sindaco",
        "prato",
        "misurato",
        "medaglia",
        "mediare",
        "mediazione",
        "mediatore",
        "medico",
        "meditare",
        "mediterraneo",
        "miscuglio",
        "ricordo",
        "memorabile",
        "rammendo",
        "mestruazioni",
        "mentore",
        "misericordioso",
        "misericordia",
        "unire",
        "merito",
        "meritorio",
        "allegria",
        "allegro",
        "metropolitano",
        "coraggio",
        "microscopia",
        "ostetrica",
        "potente",
        "mimo",
        "consapevole",
        "consapevolezza",
        "ministero",
        "miracolo",
        "miracoloso",
        "allegria",
        "missionario",
        "modello",
        "moderare",
        "moderatore",
        "modesto",
        "modestia",
        "quantità di moto",
        "monetario",
        "i soldi",
        "monaco",
        "monumento",
        "morale",
        "moralità",
        "morale",
        "mortaio",
        "maternità",
        "motivo",
        "mobile",
        "motore",
        "muscolare",
        "musica",
        "musicale",
        "mutevole",
        "reciproco",
        "pisolino",
        "naturalista",
        "navigabile",
        "ordinatamente",
        "nettare",
        "ago",
        "negoziare",
        "negoziatore",
        "vicino di casa",
        "nervo",
        "annidarsi",
        "nobiltà",
        "nobile",
        "nobile",
        "nomina",
        "normalità",
        "notevole",
        "notabili",
        "notato",
        "nozione",
        "nutrimento",
        "numeri",
        "infermiera",
        "asilo",
        "nutrire",
        "nutriente",
        "quercia",
        "oasi",
        "giuramento",
        "obbedienza",
        "obbiettivo",
        "obbligato",
        "attento",
        "ottenibile",
        "ovvio",
        "occupante",
        "occupazione",
        "occupare",
        "offerta",
        "ufficiale",
        "compensare",
        "propaggine",
        "onnisciente",
        "apertura",
        "musica lirica",
        "opportuno",
        "opportunità",
        "ottimismo",
        "ottimista",
        "opzione",
        "opzionale",
        "oracolo",
        "orazione",
        "orchestra",
        "ordinato",
        "ordinato",
        "ordinazione",
        "organico",
        "organizzazione",
        "organizzare",
        "organizzato",
        "orgasmo",
        "originalità",
        "ornato",
        "ornato",
        "risultato",
        "superare",
        "verso l'esterno",
        "felicissimo",
        "stragrande",
        "Proprietà",
        "Pacifico",
        "pad",
        "imbottitura",
        "pagaia",
        "appetibile",
        "palliativo",
        "panacea",
        "brio",
        "paniere",
        "paprica",
        "esempio",
        "fondamentale",
        "Scusi",
        "parentela",
        "parietale",
        "partecipare",
        "partecipazione",
        "compagno",
        "collaborazione",
        "passione",
        "appassionato",
        "passatempo",
        "pastore",
        "Pasticcino",
        "pascolo",
        "brevetto",
        "pazienza",
        "paziente",
        "patriarcale",
        "patrono",
        "mecenatismo",
        "pagare",
        "pace",
        "pacifico",
        "tranquillo, calmo",
        "pavone",
        "beccare",
        "peculiarità",
        "pedigree",
        "impareggiabile",
        "propensione",
        "percepire",
        "percepibile",
        "perenne",
        "Perfetto",
        "perfezione",
        "esecutore",
        "vantaggio",
        "autorizzazione",
        "perpetuo",
        "persistenza",
        "persistente",
        "gradevole",
        "pertinente",
        "farmaceutico",
        "filantropo",
        "filantropia",
        "filosofo",
        "Fenice",
        "fonetico",
        "medico",
        "fisica",
        "fisiologia",
        "fisico",
        "scegliere",
        "picnic",
        "pittoresco",
        "pietà",
        "pillola",
        "cuscino",
        "pilota",
        "culmine",
        "pioniere",
        "pio",
        "midollo",
        "perno",
        "placido",
        "pianificazione",
        "giocoso",
        "terreno di gioco",
        "teatro",
        "piacevole",
        "lieto",
        "piacevole",
        "impegno",
        "plenaria",
        "abbondante",
        "plesso",
        "prugna",
        "piombo",
        "peluche",
        "piega",
        "puntualmente",
        "Polizia Stradale",
        "poliziotto",
        "polacco",
        "lucidato",
        "educato",
        "cortesia",
        "politico",
        "piscina",
        "papa",
        "popolarità",
        "reso popolare",
        "popolazione",
        "portatile",
        "possedere",
        "potabile",
        "potenza",
        "potente",
        "con forza",
        "la pratica",
        "praticato",
        "la pratica",
        "lode",
        "lodato",
        "lodevole",
        "pregare",
        "precauzione",
        "precedere",
        "precedenza",
        "prezioso",
        "preciso",
        "precisione",
        "predilezione",
        "predominante",
        "preminente",
        "preferire",
        "premier",
        "locali",
        "preparare",
        "preparato",
        "preveggente",
        "presenza",
        "regalo",
        "presentabile",
        "conservante",
        "conserva",
        "Presidente",
        "prestigio",
        "presto",
        "bello",
        "prevalere",
        "prevenzione",
        "inestimabile",
        "orgoglio",
        "sacerdote",
        "sacerdozio",
        "sacerdotale",
        "primato",
        "primario",
        "primo",
        "primer",
        "Principe",
        "principesco",
        "Principessa",
        "principale",
        "incontaminato",
        "privilegiato",
        "probità",
        "procedura",
        "processione",
        "procuratore",
        "procurarsi",
        "prodigioso",
        "prodigio",
        "produttore",
        "produrre",
        "produzione",
        "produttivo",
        "produttività",
        "professione",
        "professionale",
        "professoressa",
        "competenza",
        "esperto",
        "abbondante",
        "progresso",
        "progressione",
        "progressivo",
        "prolifico",
        "risalto",
        "in modo prominente",
        "promettere",
        "promettente",
        "promozione",
        "puntello",
        "corretto",
        "profeta",
        "profilattico",
        "proposizione",
        "prospettiva",
        "prosperare",
        "prosperità",
        "prospero",
        "proteggere",
        "proteggere",
        "protettivo",
        "protettore",
        "orgoglioso",
        "dimostrare",
        "proverbiale",
        "fornire",
        "fornendo",
        "prudenza",
        "prudente",
        "salmo",
        "pubblico",
        "tiro",
        "pulpito",
        "puntuale",
        "puntualità",
        "cucciolo",
        "puramente",
        "purificazione",
        "purificare",
        "purista",
        "purezza",
        "fusa",
        "caratteristico",
        "qualificato",
        "qualificazione",
        "ricerca",
        "domanda",
        "rapidità",
        "quiescente",
        "silenzioso",
        "chinino",
        "splendore",
        "radiante",
        "irradiare",
        "Radio",
        "rapito",
        "rapimento",
        "razionale",
        "lettore",
        "prontamente",
        "prontezza",
        "lettura",
        "riaffermare",
        "vero",
        "Motivo",
        "rassicurazione",
        "rassicurare",
        "sconto",
        "rifusione",
        "ricevuto",
        "ricevere",
        "ricerca",
        "ricambiare",
        "bonifica",
        "reclinare",
        "riconoscibile",
        "consiglia",
        "riconciliazione",
        "Riconsiderazione",
        "ricostruire",
        "ricostruzione",
        "registratore",
        "recuperare",
        "recupero",
        "ricreazione",
        "ricreativo",
        "rettificare",
        "redenzione",
        "riparazione",
        "perfezionare",
        "raffinatezza",
        "riforma",
        "riforma",
        "riformatore",
        "rinfrescante",
        "rinnovare",
        "regale",
        "reggente",
        "regolarità",
        "regolare",
        "riabilitare",
        "riabilitazione",
        "rimborsare",
        "rimborso",
        "rinforzo",
        "reintegrare",
        "rallegrarsi",
        "gioire",
        "ringiovanire",
        "ringiovanito",
        "rilassamento",
        "pertinente",
        "affidabilità",
        "affidabile",
        "affidamento",
        "sollievo",
        "alleviare",
        "remake",
        "notevole",
        "notevolmente",
        "rimedio",
        "remissione",
        "rimodellare",
        "Rinascimento",
        "rendere",
        "rinnovo",
        "ristrutturare",
        "ristrutturazione",
        "fama",
        "rinomato",
        "riorganizzare",
        "risarcimento",
        "rimborsare",
        "pentirsi",
        "ricostituire",
        "pieno",
        "reporter",
        "riposo",
        "rappresentato",
        "riproduttivo",
        "rispettabile",
        "salvare",
        "Riserva",
        "residente",
        "resiliente",
        "resistivo",
        "risolutamente",
        "risorse",
        "rispetto",
        "rispettabilità",
        "rispettabile",
        "rispettoso",
        "rispetto",
        "rispetti",
        "tregua",
        "risplendente",
        "responsabile",
        "reattivo",
        "riposo",
        "riposante",
        "restituzione",
        "riparatore",
        "restaurare",
        "moderazione",
        "ripresa",
        "ritenzione",
        "riunione",
        "baldoria",
        "si diverte",
        "riverire",
        "riverenza",
        "reverendo",
        "fantasticheria",
        "rivedere",
        "rinascita",
        "rivoluzionario",
        "ricompensa",
        "ritmo",
        "ritmico",
        "nastro",
        "ricchezza",
        "cavaliere",
        "giusto",
        "legittimo",
        "giustamente",
        "maturo",
        "maturare",
        "in aumento",
        "avvincente",
        "roadster",
        "robusto",
        "roccia",
        "asta",
        "rotolando",
        "romanza",
        "romantico",
        "romanticismo",
        "scatenarsi",
        "radicato",
        "roseo",
        "ruota",
        "routine",
        "regalità",
        "rubrica",
        "ruth",
        "sicuro",
        "salvaguardia",
        "saggio",
        "santo",
        "santo",
        "stipendio",
        "saliente",
        "salutare",
        "saluto",
        "salvezza",
        "unguento",
        "samurai",
        "santificazione",
        "santificare",
        "santuario",
        "sanguigno",
        "sanitario",
        "raso",
        "in modo soddisfacente",
        "soddisfatto",
        "Salva",
        "risparmio",
        "assaporare",
        "salato",
        "esperto",
        "studioso",
        "borsa di studio",
        "scientifico",
        "scienziato",
        "scintilla",
        "punto",
        "scriba",
        "sceneggiatura",
        "delizioso",
        "scultura",
        "mare",
        "sigillo",
        "condito",
        "segreteria",
        "anzianità",
        "sensazionale",
        "senso",
        "sensibilità",
        "Sensibilmente",
        "sensualità",
        "sensuale",
        "sentimentale",
        "sentimentalismo",
        "sentinella",
        "serenità",
        "sermone",
        "siero",
        "disponente",
        "sesso",
        "forma",
        "formosa",
        "Condividere",
        "riparo",
        "pastore",
        "splendore",
        "splendente",
        "acquisti",
        "spalla",
        "scaltro",
        "seta",
        "semplificare",
        "sincero",
        "sincerità",
        "cantare",
        "singolarmente",
        "signore",
        "sorellanza",
        "abile",
        "abile",
        "cielo",
        "ardesia",
        "elegante",
        "snello",
        "magra",
        "Sorridi",
        "sorridente",
        "colpito",
        "levigatezza",
        "risatina",
        "sobrietà",
        "socievole",
        "conforto",
        "soldato",
        "solido",
        "solidità",
        "soluzione",
        "solvibilità",
        "sonar",
        "sonata",
        "sonetto",
        "sonoro",
        "lenire",
        "calmante",
        "selezionatore",
        "solidità",
        "la minestra",
        "terme",
        "spazioso",
        "spaniel",
        "brillare",
        "speciale",
        "specie",
        "discorso",
        "veloce",
        "ortografia",
        "Spezia",
        "spirito",
        "spiriti",
        "splendida",
        "splendore",
        "sponsor",
        "immacolato",
        "Sposa",
        "abete rosso",
        "stabile",
        "staccato",
        "inossidabile",
        "stallone",
        "fedele",
        "resistenza",
        "in piedi",
        "stella",
        "luce delle stelle",
        "stellato",
        "maestoso",
        "dichiarazione",
        "statua",
        "stato",
        "fedele",
        "costante",
        "stellare",
        "steward",
        "quiete",
        "negozio",
        "semplice",
        "strategico",
        "stratega",
        "forza",
        "rafforzare",
        "rafforzamento",
        "Impressionante",
        "sorprendentemente",
        "fortemente",
        "struttura",
        "perno",
        "studia",
        "robusto",
        "sublimazione",
        "sostanza",
        "sostanziale",
        "avere successo",
        "riuscendo",
        "successo",
        "riuscito",
        "succinto",
        "sufficienza",
        "zucchero",
        "adatto",
        "afoso",
        "sole",
        "soleggiato",
        "tramonto",
        "luce del sole",
        "superbo",
        "sovrumano",
        "superiore",
        "superiorità",
        "superuomo",
        "superstar",
        "supplica",
        "forniture",
        "la fornitura",
        "supportato",
        "sostenitore",
        "supporto",
        "supremo",
        "supremamente",
        "fideiussione",
        "supporre",
        "superando",
        "sorpresa",
        "ispezionando",
        "sopravvivere",
        "imprecare",
        "dolce",
        "tesoro",
        "dolcezza",
        "dolcezza",
        "dolci",
        "veloce",
        "nuotare",
        "simbolico",
        "simmetrico",
        "simmetria",
        "comprensivo",
        "simpatia",
        "sinfonia",
        "sincronizzare",
        "sinergico",
        "sinodo",
        "tatto",
        "racconto",
        "talento",
        "talismano",
        "parlare",
        "abbronzato",
        "compito",
        "di buon gusto",
        "gustoso",
        "insegnare",
        "insegnante",
        "tecnologia",
        "temperanza",
        "temperato",
        "sostenibile",
        "tenace",
        "tenacia",
        "locazione",
        "inquilino",
        "tenero",
        "tenerezza",
        "grato",
        "ringraziamento",
        "teorico",
        "terapeutico",
        "terapeutici",
        "pensatore",
        "purosangue",
        "premuroso",
        "premurosità",
        "parsimonia",
        "brivido",
        "emozionante",
        "fiorente",
        "trono",
        "solletico",
        "piastrellatura",
        "tempestivo",
        "orpelli",
        "titolo",
        "pane abbrustolito",
        "tollerante",
        "tolleranza",
        "superiore",
        "durezza",
        "Torre",
        "torreggiante",
        "tradizionale",
        "tranquillo",
        "la tranquillità",
        "trascendenza",
        "trascendentale",
        "in viaggio",
        "tesoro",
        "albero",
        "tremendamente",
        "tendenza",
        "di tendenza",
        "affluente",
        "omaggio",
        "trigono",
        "trionfo",
        "trionfante",
        "trofeo",
        "tregua",
        "True",
        "fidato",
        "verità",
        "veridicità",
        "tutela",
        "tutore",
        "gemello",
        "scintillio",
        "in definitiva",
        "arbitro",
        "unanimità",
        "unanime",
        "senza pretese",
        "imparziale",
        "infrangibile",
        "ininterrotto",
        "non vincolato",
        "sottolineare",
        "comprensione",
        "sottoscrivere",
        "indiviso",
        "immortale",
        "inequivocabilmente",
        "svelare",
        "unificazione",
        "uniformemente",
        "non infetto",
        "unico",
        "all'unisono",
        "unitario",
        "unito",
        "unità",
        "Università",
        "illimitato",
        "senza pretese",
        "indiscutibile",
        "indiscutibilmente",
        "indiscusso",
        "illeso",
        "altruista",
        "insuperabile",
        "incrollabile",
        "elevazione",
        "verticale",
        "utilità",
        "usciere",
        "solito",
        "utilità",
        "utopico",
        "vacanza",
        "vaccino",
        "valoroso",
        "valore",
        "prezioso",
        "avanguardia",
        "vincere",
        "velluto",
        "vellutato",
        "venerabile",
        "venerazione",
        "veridicità",
        "verdeggiante",
        "verifica",
        "verificato",
        "in verità",
        "vero",
        "primaverile",
        "verve",
        "veterano",
        "vicario",
        "vincitore",
        "vittorioso",
        "vittoria",
        "vigilanza",
        "vigile",
        "vigore",
        "vigoroso",
        "abitante del villaggio",
        "rivendicato",
        "rivendicazione",
        "vergine",
        "verginità",
        "virtù",
        "virtuoso",
        "visione",
        "visionario",
        "visitare",
        "visitatore",
        "vitale",
        "vitalità",
        "vivace",
        "vivido",
        "vocabolario",
        "volontario",
        "voluttuoso",
        "garantire",
        "voto",
        "salari",
        "garanzia",
        "guerriero",
        "cane da guardia",
        "vigile",
        "guardiano",
        "impermeabile",
        "ricchezza",
        "resistente alle intemperie",
        "accolto",
        "bianca",
        "bianchezza",
        "sano",
        "wicket",
        "molto diffuso",
        "volentieri",
        "volontà",
        "manna",
        "vincitore",
        "vincente",
        "vincite",
        "senza fili",
        "wis",
        "saggezza",
        "saggio",
        "spirito",
        "resistere",
        "ingegno",
        "spiritoso",
        "procedura guidata",
        "grembo",
        "meraviglioso",
        "meravigliosamente",
        "meraviglioso",
        "parola",
        "Lavorando",
        "culto",
        "di valore",
        "degno",
        "vabbè",
        "scrittore",
        "giovane",
        "minore",
        "gioventù",
        "zelo",
        "zelante",
        "scorza",
    ]
)

_negative = set(
    [
        "abbandono",
        "abbandonato",
        "abbandono",
        "rapimento",
        "aberrante",
        "aberrazione",
        "aborrire",
        "aberrante",
        "abietto",
        "anormale",
        "abolire",
        "abolizione",
        "abominevole",
        "abominio",
        "abortire",
        "aborto",
        "abortivo",
        "abrasione",
        "abrogare",
        "ascesso",
        "assenza",
        "assente",
        "assente",
        "assenteismo",
        "assurdo",
        "assurdità",
        "abuso",
        "abissale",
        "abisso",
        "incidente",
        "accidentale",
        "maledetto",
        "accusa",
        "accusativo",
        "accusato",
        "accusatore",
        "accusando",
        "dolore",
        "dolorante",
        "acido",
        "perseguibile",
        "sommatore",
        "dipendenza",
        "adiposo",
        "giudicare",
        "ammonimento",
        "alla deriva",
        "adulterato",
        "adulterio",
        "avversario",
        "avverso",
        "avversità",
        "affliggere",
        "afflitto",
        "afflizione",
        "affronto",
        "paura",
        "conseguenze",
        "retrogusto",
        "aggravato",
        "aggravante",
        "aggravamento",
        "aggressione",
        "aggressivo",
        "aggressore",
        "inorridito",
        "agitato",
        "agitazione",
        "agonizzante",
        "agonia",
        "arenato",
        "ail",
        "malato",
        "senza scopo",
        "va in onda",
        "allarme",
        "allarmante",
        "alcolismo",
        "alieno",
        "alienare",
        "alienato",
        "alienazione",
        "alimenti",
        "accusa",
        "asserire",
        "distaccato",
        "alterco",
        "ambiguo",
        "imboscata",
        "amnesia",
        "anfetamine",
        "anaconda",
        "anale",
        "anarchismo",
        "anarchico",
        "anarchia",
        "anatema",
        "antico",
        "la rabbia",
        "angina",
        "pescare",
        "arrabbiato",
        "angoscia",
        "animosità",
        "animo",
        "annientare",
        "annientato",
        "annientamento",
        "infastidire",
        "fastidio",
        "fastidioso",
        "annullare",
        "annullamento",
        "anomalia",
        "anonimo",
        "antagonismo",
        "antagonista",
        "antagonista",
        "antrace",
        "anticristo",
        "antipatia",
        "antiquato",
        "antisociale",
        "antitesi",
        "ansia",
        "ansioso",
        "apache",
        "apatico",
        "apatia",
        "afide",
        "spaventoso",
        "appendicite",
        "apprensione",
        "apprensivo",
        "appropriazione",
        "arcaico",
        "arduo",
        "litigare",
        "discussione",
        "argomentativo",
        "arido",
        "armamenti",
        "citazione in giudizio",
        "arretrati",
        "arresto",
        "arroganza",
        "arrogante",
        "arsenico",
        "incendio doloso",
        "artiglieria",
        "cenere",
        "si vergogna",
        "ceneri",
        "culo",
        "assalire",
        "assalitore",
        "assassino",
        "assassinare",
        "assassinio",
        "assalto",
        "Stronzo",
        "smarrito",
        "astringente",
        "asilo",
        "ateismo",
        "aterosclerosi",
        "atroce",
        "atrocità",
        "atrofia",
        "attacco",
        "attaccare",
        "attenuato",
        "attenuazione",
        "audacia",
        "austero",
        "austerità",
        "autocratico",
        "autopsia",
        "valanga",
        "avarizia",
        "vendicatore",
        "avverso",
        "avversione",
        "evitare",
        "evitare",
        "terribile",
        "imbarazzo",
        "storto",
        "balbettio",
        "balbettio",
        "babbuino",
        "indietro",
        "indietro",
        "arretrato",
        "batteri",
        "batterio",
        "cattivo",
        "tasso",
        "male",
        "cattiveria",
        "ufficiale giudiziario",
        "esca",
        "balla",
        "esitare",
        "bandire",
        "bandito",
        "male",
        "scoppio",
        "botto",
        "bandire",
        "bandito",
        "esilio",
        "fallito",
        "fallimento",
        "banshee",
        "barba",
        "barbaro",
        "barbaro",
        "barbarie",
        "abbaio",
        "sbarrato",
        "sterile",
        "barricata",
        "barriera",
        "infondato",
        "bastardo",
        "pastella",
        "malconcio",
        "batteria",
        "battaglia",
        "combattuto",
        "campo di battaglia",
        "osceno",
        "baionetta",
        "portatore",
        "bestia",
        "bestiale",
        "battere",
        "accadrà",
        "elemosinare",
        "mendicante",
        "mendicare",
        "Behemoth",
        "visto",
        "tardivo",
        "sminuire",
        "belligerante",
        "cintura",
        "piegarsi",
        "Persona in lutto",
        "lutto",
        "privo",
        "berserk",
        "bestiale",
        "tradire",
        "tradimento",
        "attenzione",
        "disorientato",
        "pregiudizio",
        "prevenuto",
        "litigare",
        "bara",
        "bigotto",
        "bigotto",
        "bile",
        "biopsia",
        "betulla",
        "luogo di nascita",
        "cagna",
        "mordere",
        "amaramente",
        "amarezza",
        "bizzarro",
        "Nero",
        "blackjack",
        "ricatto",
        "oscurità",
        "colpa",
        "blando",
        "blasfemo",
        "bestemmia",
        "raffica",
        "sfacciato",
        "blaterare",
        "fiammata",
        "spoglio",
        "sanguinamento",
        "macchia",
        "peronospora",
        "rovinato",
        "cieco",
        "accecato",
        "ciecamente",
        "cecità",
        "vescica",
        "gonfio",
        "macchia",
        "blocco",
        "spargimento di sangue",
        "sanguinario",
        "sanguinante",
        "macchia",
        "soffiatore",
        "spegnere",
        "blues",
        "bluff",
        "errore",
        "sfocatura",
        "sfocato",
        "arrossire",
        "vantarsi",
        "palude",
        "falso",
        "Bollire",
        "boilerplate",
        "bomba",
        "bombardare",
        "bombardamento",
        "bombardato",
        "schiavitù",
        "obbligazioni",
        "boh",
        "booby",
        "liquore",
        "foro",
        "la noia",
        "noioso",
        "mutuatario",
        "fastidio",
        "fastidioso",
        "parte inferiore",
        "legato",
        "incontro",
        "bovino",
        "ragazzo",
        "boicottare",
        "vantarsi",
        "Brandy",
        "spavalderia",
        "rissa",
        "sfacciato",
        "violazione",
        "guasto",
        "a rotta di collo",
        "rottura",
        "tangente",
        "corruzione",
        "brigata",
        "zolfo",
        "setola",
        "fiancata",
        "grigliare",
        "rotto",
        "rotte",
        "bordello",
        "ammaccare",
        "bruciato",
        "brutale",
        "brutalità",
        "bruto",
        "buffet",
        "insetto",
        "spauracchio",
        "bulboso",
        "prepotente",
        "culo",
        "peccato",
        "gravoso",
        "burocrazia",
        "burocrate",
        "ladro",
        "furto",
        "sepoltura",
        "sepolto",
        "burke",
        "bruciato",
        "arrestato",
        "macellaio",
        "culo",
        "ronzato",
        "cabala",
        "cacofonia",
        "ca",
        "cadavere",
        "gabbia",
        "calcolare",
        "insensibile",
        "chiamate",
        "campagna",
        "Annulla",
        "cancro",
        "cancro",
        "cannibale",
        "cannibalismo",
        "cannone",
        "prigioniero",
        "cattività",
        "rapitore",
        "catturare",
        "carcassa",
        "carcinoma",
        "cardiomiopatia",
        "incuria",
        "caricatura",
        "carie",
        "carneficina",
        "carnale",
        "carnivoro",
        "cartello",
        "Astuccio",
        "scrigno",
        "casta",
        "vittima",
        "cataratta",
        "catastrofe",
        "catetere",
        "attenzione",
        "cedere",
        "cimitero",
        "censurare",
        "censura",
        "cess",
        "cessazione",
        "pula",
        "sfregamento",
        "dispiacere",
        "sfida",
        "caos",
        "caotico",
        "sciarada",
        "a pagamento",
        "caccia",
        "castigo",
        "loquace",
        "a buon mercato",
        "imbroglione",
        "torta di formaggio",
        "chicane",
        "infantile",
        "freddo",
        "cloroformio",
        "soffocamento",
        "colera",
        "taglio",
        "lavoretto",
        "cronico",
        "sigaretta",
        "clamore",
        "scontrarsi",
        "scontrandosi",
        "artiglio",
        "chiostro",
        "offuscato",
        "nuvolosità",
        "ciuffo",
        "goffo",
        "cocaina",
        "costringere",
        "coercizione",
        "bara",
        "freddo",
        "freddamente",
        "freddezza",
        "colica",
        "crollo",
        "collisione",
        "collusione",
        "coma",
        "comatoso",
        "combattere",
        "combattente",
        "combattivo",
        "impegno",
        "commozione",
        "comunismo",
        "comunista",
        "concorrenza",
        "reclamo",
        "rimostranza",
        "complessato",
        "complessità",
        "complicato",
        "complicato",
        "complicazione",
        "compost",
        "costrizione",
        "obbligatorio",
        "nascondere",
        "nascosto",
        "occultamento",
        "presunzione",
        "presuntuoso",
        "concussione",
        "condannare",
        "condanna",
        "condiscendente",
        "condiscendenza",
        "confessione",
        "confinare",
        "confinato",
        "confinamento",
        "confiscare",
        "confisca",
        "conflagrazione",
        "conflitto",
        "conflitto",
        "confondere",
        "confuso",
        "confuso",
        "confusione",
        "congestione",
        "evocazione",
        "conquista",
        "cospiratore",
        "cospirare",
        "costernazione",
        "stipsi",
        "vincolare",
        "costretto",
        "vincolo",
        "contagio",
        "contagioso",
        "contaminare",
        "contaminato",
        "contaminazione",
        "disprezzo",
        "spregevole",
        "sprezzante",
        "contenzioso",
        "contrabbando",
        "contratto",
        "contraddire",
        "contraddizione",
        "contraddittorio",
        "contrario",
        "contrastato",
        "contravvenire",
        "contravvenzione",
        "controverso",
        "controversia",
        "condannato",
        "convinzione",
        "cooperativa",
        "copia",
        "copione",
        "medico legale",
        "caporale",
        "cadavere",
        "correzione",
        "corrosione",
        "corrosivo",
        "corrotto",
        "corrompere",
        "corruzione",
        "tosse",
        "consulente",
        "corso",
        "bramare",
        "codardo",
        "viltà",
        "vigliaccamente",
        "scorbutico",
        "crepa",
        "incrinato",
        "cracking",
        "crampo",
        "angusto",
        "manovella",
        "irritabile",
        "merda",
        "incidente",
        "strisciare",
        "pazzo",
        "pazzo",
        "scricchiolando",
        "creatura",
        "strisciamento",
        "crimine",
        "penale",
        "criminalità",
        "imbarazzante",
        "storpio",
        "paralizzato",
        "crisi",
        "croccante",
        "critico",
        "critica",
        "criticare",
        "truffatore",
        "attraverso",
        "accovacciato",
        "crociato",
        "crocifissione",
        "greggio",
        "crudele",
        "crudelmente",
        "crudeltà",
        "sgretolando",
        "scricchiolio",
        "crociata",
        "schiacciato",
        "schiacciamento",
        "croccante",
        "piangere",
        "pianto",
        "cripta",
        "becco",
        "cuculo",
        "abbattere",
        "colpevolezza",
        "colpevole",
        "colpevole",
        "culto",
        "ingombrante",
        "coppettazione",
        "ca",
        "maledizione",
        "maledetto",
        "maledicendo",
        "superficiale",
        "taglierina",
        "tagliagole",
        "taglio",
        "cianuro",
        "ciclone",
        "cisti",
        "citomegalovirus",
        "dilettarsi",
        "demone",
        "sciocco",
        "pugnale",
        "danno",
        "danni",
        "dannazione",
        "dannazione",
        "dannato",
        "ammortizzatore",
        "forfora",
        "dandy",
        "Pericolo",
        "pericoloso",
        "scurire",
        "oscurato",
        "buio",
        "tratteggiato",
        "vile",
        "stordito",
        "disattivare",
        "punto morto",
        "mortale",
        "sordo",
        "Morte",
        "debacle",
        "dissolutezza",
        "detriti",
        "debito",
        "debitore",
        "decadimento",
        "decaduto",
        "deceduto",
        "inganno",
        "ingannevole",
        "ingannare",
        "ingannato",
        "ingannando",
        "inganno",
        "ingannevole",
        "declinazione",
        "declino",
        "in declino",
        "decomposizione",
        "diminuire",
        "decremento",
        "decrepito",
        "deplorare",
        "dedurre",
        "diffamazione",
        "diffamatorio",
        "predefinito",
        "sconfitta",
        "sconfitto",
        "difetto",
        "defezione",
        "difettoso",
        "indifeso",
        "differimento",
        "sfida",
        "ribelle",
        "carenza",
        "disavanzo",
        "sgonfiare",
        "deflazione",
        "deformare",
        "deforme",
        "deformità",
        "frodare",
        "defunto",
        "sfidare",
        "degenerazione",
        "degenerare",
        "degradazione",
        "degradare",
        "degradante",
        "ritardo",
        "ritardato",
        "deleterio",
        "cancellazione",
        "delinquenza",
        "delinquente",
        "delirante",
        "delirio",
        "diluvio",
        "illusione",
        "delirante",
        "domanda",
        "esigente",
        "demente",
        "demenza",
        "decesso",
        "demolire",
        "demolizione",
        "demone",
        "demoniaco",
        "demoralizzato",
        "rifiuto",
        "negato",
        "denunciare",
        "denuncia",
        "negare",
        "negare",
        "partito",
        "partenza",
        "dipendenza",
        "dipendenza",
        "deplorevole",
        "deplorare",
        "deportazione",
        "deportazione",
        "depravato",
        "depravazione",
        "deprezzarsi",
        "ammortizzato",
        "ammortamento",
        "deprimere",
        "depresso",
        "deprimente",
        "depressione",
        "depressivo",
        "privazione",
        "squilibrato",
        "derelitto",
        "derisione",
        "deroga",
        "dispregiativo",
        "profanazione",
        "deserto",
        "abbandonato",
        "diserzione",
        "desistere",
        "desolazione",
        "disperazione",
        "disperando",
        "disperato",
        "spregevole",
        "disprezzare",
        "dispotico",
        "dispotismo",
        "indigente",
        "distrutto",
        "distruttore",
        "distruggendo",
        "distruzione",
        "distruttivo",
        "distacco",
        "trattenere",
        "detenuto",
        "detenzione",
        "deteriorare",
        "deteriorato",
        "deterioramento",
        "detestare",
        "Detonare",
        "sottrarre",
        "danno",
        "dannoso",
        "detriti",
        "devastare",
        "devastante",
        "devastazione",
        "diavolo",
        "diabolico",
        "subdolo",
        "devoluzione",
        "divorare",
        "diabolico",
        "diagnosi",
        "diatriba",
        "dittatore",
        "dittatoriale",
        "dittatura",
        "morire",
        "le difficoltà",
        "difficoltà",
        "divagazione",
        "fatiscente",
        "diluire",
        "diminuire",
        "diminuito",
        "din",
        "terribile",
        "sporco",
        "sporco",
        "disabilità",
        "disattivare",
        "Disabilitato",
        "disamorato",
        "disaccordo",
        "in disaccordo",
        "disaccordo",
        "non consentito",
        "deludere",
        "deluso",
        "deludente",
        "delusione",
        "disapprovazione",
        "disapprovare",
        "disapprovato",
        "disapprovazione",
        "disastro",
        "disastroso",
        "non crederci",
        "scarti",
        "scarico",
        "disciplina",
        "diniego",
        "scolorimento",
        "scolorito",
        "disagio",
        "disconnettersi",
        "disconnesso",
        "disconnessione",
        "malcontento",
        "interrompere",
        "discontinuità",
        "discordia",
        "scoraggiare",
        "scoraggiamento",
        "discredito",
        "discriminare",
        "discriminante",
        "discriminazione",
        "disprezzo",
        "patologia",
        "malato",
        "disincarnato",
        "disimpegno",
        "sfigurato",
        "disgrazia",
        "caduto in disgrazia",
        "vergognoso",
        "scontento",
        "disgusto",
        "disgustoso",
        "scoraggiato",
        "scoraggiante",
        "disonesto",
        "disonestà",
        "disonore",
        "disillusione",
        "disinformazione",
        "falso",
        "disintegrarsi",
        "disintegrazione",
        "disinteressato",
        "antipatia",
        "non piaceva",
        "dislocato",
        "triste",
        "sgomento",
        "smembramento",
        "licenziamento",
        "disobbedienza",
        "disobbediente",
        "disobbedire",
        "disturbo",
        "disordinato",
        "disorganizzato",
        "screditare",
        "denigratorio",
        "disparità",
        "spassionato",
        "dissipare",
        "dispersione",
        "spostare",
        "dispiaciuto",
        "dispiacere",
        "disposizione",
        "espropriato",
        "controversia",
        "squalifica",
        "squalificato",
        "squalificare",
        "ignorare",
        "ignorato",
        "poco raccomandabile",
        "mancanza di rispetto",
        "irrispettoso",
        "interruzione",
        "insoddisfazione",
        "dissenso",
        "dissenziente",
        "disservizio",
        "dissidente",
        "dissoluzione",
        "dissonanza",
        "disgusto",
        "sgradevole",
        "distorto",
        "distorsione",
        "distrarre",
        "distratto",
        "distraendo",
        "distrazione",
        "sconvolto",
        "angoscia",
        "angosciato",
        "angosciante",
        "diffidenza",
        "disturbo",
        "disturbato",
        "disuso",
        "in disuso",
        "divergente",
        "ceduto",
        "disinvestimento",
        "divorzio",
        "vertigini",
        "dare le vertigini",
        "ancorato",
        "fallo",
        "stasi",
        "sussidio",
        "dolor",
        "dominante",
        "dominio",
        "asino",
        "scarabocchio",
        "destino",
        "condannato",
        "giorno del giudizio",
        "dubbio",
        "dubbioso",
        "dubitare",
        "doccia",
        "austero",
        "Caduta",
        "scialbo",
        "drenaggio",
        "inconveniente",
        "paura",
        "terribile",
        "terribilmente",
        "triste",
        "potabile",
        "sciocchezze",
        "drone",
        "cadente",
        "siccità",
        "annegare",
        "sonnolenza",
        "fatica",
        "ubriaco",
        "ubriachezza",
        "dubbioso",
        "noioso",
        "attutire",
        "manichino",
        "discariche",
        "no",
        "prigione",
        "ingannare",
        "duplicità",
        "costrizione",
        "polvere",
        "sminuito",
        "sta morendo",
        "dissenteria",
        "terremoto",
        "origliare",
        "editto",
        "effeminato",
        "egoistico",
        "egregio",
        "espellere",
        "espulsione",
        "eliminazione",
        "sfuggente",
        "emaciato",
        "embargo",
        "imbarazzare",
        "imbarazzante",
        "imbarazzo",
        "appropriazione indebita",
        "embolia",
        "invischiato",
        "emergenza",
        "enclave",
        "invasione",
        "ingombro",
        "mettere in pericolo",
        "in via di estinzione",
        "endemico",
        "nemico",
        "rinforzo",
        "enigmatico",
        "inimicizia",
        "rendere schiavo",
        "reso schiavo",
        "asservimento",
        "impigliato",
        "intreccio",
        "viscere",
        "invidioso",
        "epidemico",
        "epilessia",
        "sradicare",
        "eradicazione",
        "cancellare",
        "erosione",
        "err",
        "errante",
        "irregolare",
        "errore",
        "errato",
        "errore",
        "eruttare",
        "eruzione",
        "intensificare",
        "evitare",
        "spionaggio",
        "estraniato",
        "eutanasia",
        "evacuare",
        "evacuazione",
        "eludere",
        "evasione",
        "sfrattare",
        "sfratto",
        "il male",
        "esacerbare",
        "esacerbazione",
        "esigente",
        "esagerare",
        "esagerato",
        "visita medica",
        "esasperazione",
        "scavo",
        "eccesso",
        "accise",
        "escluso",
        "escluso",
        "esclusione",
        "escrementi",
        "straziante",
        "scusa",
        "esecuzione",
        "boia",
        "scarico",
        "esausto",
        "esaurimento",
        "esigente",
        "esilio",
        "esorcismo",
        "espatriato",
        "espellere",
        "spesa",
        "spese",
        "scadono",
        "è scaduto",
        "imprecazione",
        "esplodere",
        "esplosione",
        "esplosivo",
        "esposto",
        "espropriazione",
        "espulsione",
        "sterminare",
        "sterminio",
        "estinto",
        "spegnere",
        "stragiudiziale",
        "estremità",
        "fabbricare",
        "fabbricazione",
        "dissolvenza",
        "feci",
        "fallendo",
        "fallimento",
        "svenimento",
        "infedele",
        "impostore",
        "autunno",
        "fallace",
        "fallacia",
        "fallibile",
        "cadente",
        "maggese",
        "falsità",
        "falsamente",
        "falsificazione",
        "falsificare",
        "falsità",
        "vacillare",
        "carestia",
        "fanatico",
        "palcoscenico",
        "farsesco",
        "digiuno",
        "Grasso",
        "fatale",
        "fatalità",
        "destino",
        "fatica",
        "affaticato",
        "Grasso",
        "colpa",
        "difettoso",
        "fulvo",
        "paura",
        "pauroso",
        "pieno di paura",
        "temendo",
        "febbrile",
        "fecale",
        "feci",
        "tassa",
        "flebile",
        "finto",
        "caduto",
        "criminale",
        "crimine",
        "fermento",
        "feroce",
        "ferocia",
        "feudo",
        "feudale",
        "feudalesimo",
        "febbrile",
        "fiasco",
        "fib",
        "volubile",
        "fittizio",
        "diavolo",
        "feroce",
        "combattere",
        "battagliero",
        "filibustiere",
        "sporcizia",
        "sporco",
        "armi da fuoco",
        "si adatta",
        "flaccido",
        "flaccido",
        "bandiera",
        "flagrante",
        "fiocco",
        "lembo",
        "flatulenza",
        "ostentare",
        "difetto",
        "Pulce",
        "fuggire",
        "pile",
        "carnoso",
        "sussultare",
        "flagello",
        "flop",
        "platessa",
        "influenza",
        "fluttuazione",
        "nemico",
        "sventato",
        "follia",
        "stolto",
        "folle",
        "follia",
        "foraggio",
        "incursione",
        "proibire",
        "proibito",
        "forza",
        "costretto",
        "forzatamente",
        "presagio",
        "precludere",
        "rinunciare",
        "straniera",
        "straniero",
        "avvisato",
        "perdere",
        "decaduto",
        "decadenza",
        "contraffazione",
        "dimenticare",
        "dimenticato",
        "abbandonato",
        "informe",
        "fornicazione",
        "abbandonare",
        "abbandonato",
        "ripugnante",
        "frattura",
        "fragile",
        "fragilità",
        "frenetico",
        "frode",
        "fraudolento",
        "irto",
        "mischia",
        "sfilacciato",
        "bizzarro",
        "congelamento",
        "frenetico",
        "frenetico",
        "frenesia",
        "tasto",
        "paura",
        "impaurire",
        "spaventati",
        "spaventoso",
        "gelido",
        "frivolo",
        "congelamento",
        "schiuma",
        "cipiglio",
        "accigliato",
        "infruttuoso",
        "frustrare",
        "frustrato",
        "frustrazione",
        "truffa",
        "fuggitivo",
        "armeggiare",
        "fumi",
        "fumante",
        "fungo",
        "funk",
        "furioso",
        "furore",
        "furia",
        "chiasso",
        "pignolo",
        "futile",
        "futilità",
        "gaby",
        "bavaglio",
        "fiele",
        "forca",
        "gioco d'azzardo",
        "giocatore",
        "gioco d'azzardo",
        "banda",
        "carcere",
        "spacco",
        "spazzatura",
        "sgargiante",
        "contorno",
        "squarcio",
        "ansimando",
        "goffo",
        "scarno",
        "gentiluomo",
        "geriatrico",
        "orribile",
        "ghetto",
        "spettrale",
        "incomprensibile",
        "glaciale",
        "bagliore",
        "abbagliante",
        "disinvolto",
        "oscurità",
        "cupola",
        "glum",
        "eccesso",
        "gola",
        "gnomo",
        "folletto",
        "senza Dio",
        "gonorrea",
        "gelatina",
        "incornare",
        "gola",
        "gorilla",
        "cruento",
        "pettegolezzo",
        "sgorbiare",
        "gotta",
        "governo",
        "preda",
        "afferrare",
        "grattugiare",
        "grattugiato",
        "grattugiare",
        "grave",
        "avidità",
        "avido",
        "bomba a mano",
        "dolore",
        "rancore",
        "addolorarsi",
        "grave",
        "cupo",
        "sporcizia",
        "sudicio",
        "macinazione",
        "macabro",
        "grizzly",
        "gemito",
        "brancolare",
        "schifoso",
        "grottesco",
        "a terra",
        "infondato",
        "ringhiare",
        "ringhiando",
        "rancore",
        "a malincuore",
        "raccapricciante",
        "burbero",
        "brontolare",
        "scontroso",
        "guerriglia",
        "astuzia",
        "ghigliottina",
        "colpevolezza",
        "colpevole",
        "maschera",
        "gabbiano",
        "credulone",
        "pistola",
        "sgorgare",
        "tracannando",
        "zingaro",
        "strega",
        "smunto",
        "peloso",
        "a metà",
        "allucinazione",
        "cavezza",
        "esitante",
        "ostacolare",
        "tendine del ginocchio",
        "handicap",
        "impiccagione",
        "boia",
        "molestare",
        "presagio",
        "indurito",
        "durezza",
        "difficoltà",
        "prostituta",
        "danno",
        "dannoso",
        "straziante",
        "harry",
        "durezza",
        "hash",
        "hashish",
        "frettoloso",
        "odiare",
        "odioso",
        "odiare",
        "odio",
        "altezzoso",
        "infestare",
        "infestato",
        "caos",
        "rischio",
        "pericoloso",
        "foschia",
        "male alla testa",
        "inebriante",
        "udito",
        "sentito dire",
        "carro funebre",
        "angoscia",
        "bruciore di stomaco",
        "senza cuore",
        "pagano",
        "pesantemente",
        "tacco",
        "intensificare",
        "atroce",
        "inferno",
        "infernale",
        "impotente",
        "impotenza",
        "emorragia",
        "emorroidi",
        "eresia",
        "eretico",
        "ermafrodita",
        "eroina",
        "herpes",
        "herpesvirus",
        "esitazione",
        "nascosto",
        "orribile",
        "ostacolante",
        "ostacolo",
        "hippy",
        "sibilo",
        "sibilante",
        "colpo",
        "finora",
        "alveare",
        "rauca",
        "canuto",
        "burlare",
        "vagabondo",
        "maiale",
        "vuoto",
        "olocausto",
        "senzatetto",
        "nostalgia di casa",
        "omicida",
        "omicidio",
        "omosessualità",
        "cappuccio",
        "agganciata",
        "fischio",
        "senza speranza",
        "senza speranza",
        "orda",
        "orribile",
        "orribilmente",
        "orribile",
        "orribile",
        "inorridito",
        "orribile",
        "orrore",
        "orrori",
        "ostaggio",
        "ostile",
        "ostilità",
        "ostilità",
        "ululare",
        "sbuffo",
        "imbroglio",
        "umiliare",
        "umiliante",
        "umiliazione",
        "intuizione",
        "Affamato",
        "cacciatore",
        "a caccia",
        "uragano",
        "affrettato",
        "male",
        "doloroso",
        "male",
        "imbroglione",
        "idra",
        "idrocefalo",
        "montatura pubblicitaria",
        "iperbole",
        "ipocrisia",
        "ipocrita",
        "ipocrita",
        "isteria",
        "isterico",
        "idiozia",
        "idiota",
        "idiota",
        "pigro",
        "idolatria",
        "ignoranza",
        "ignorante",
        "ignorare",
        "malato",
        "illegale",
        "illegalità",
        "illeggibile",
        "illegittimo",
        "illecito",
        "analfabeta",
        "malattia",
        "illogico",
        "illusione",
        "imitato",
        "imitazione",
        "immaturo",
        "immaturità",
        "immorale",
        "immoralità",
        "compromettere",
        "menomazione",
        "impraticabile",
        "impazienza",
        "impaziente",
        "impeachment",
        "incriminazione",
        "impedire",
        "imperfezione",
        "imperfetto",
        "impersonare",
        "rappresentazione",
        "implacabile",
        "implicare",
        "scortese",
        "imposizione",
        "impossibile",
        "impotenza",
        "impotente",
        "sequestrare",
        "impraticabile",
        "imprigionare",
        "imprigionato",
        "reclusione",
        "scorrettezza",
        "imprudente",
        "impuro",
        "impurità",
        "imputazione",
        "incapacità",
        "inaccessibile",
        "impreciso",
        "inazione",
        "inattività",
        "inadeguatezza",
        "inadeguato",
        "inammissibile",
        "sciocco",
        "inapplicabile",
        "non appropriato",
        "disattenzione",
        "impercettibile",
        "incalcolabile",
        "incapacità",
        "incarcerazione",
        "nel caso",
        "incendiario",
        "incenso",
        "incessante",
        "incesto",
        "incestuoso",
        "incenerimento",
        "incitare",
        "inclemente",
        "incoerente",
        "incompatibile",
        "incompetenza",
        "incompetente",
        "incompletezza",
        "incomprensibile",
        "incongruo",
        "irrilevante",
        "sconsiderato",
        "incoerenza",
        "sconveniente",
        "errato",
        "incredulo",
        "incriminazione",
        "incubo",
        "incorrere",
        "incurabile",
        "incursione",
        "indecente",
        "indecisione",
        "indeciso",
        "indifendibile",
        "indennizzare",
        "contratto",
        "indeterminato",
        "incriminare",
        "accusa",
        "indifferenza",
        "indigente",
        "indignato",
        "indignazione",
        "indistinto",
        "indottrinamento",
        "indolente",
        "inefficace",
        "inefficace",
        "inefficienza",
        "inefficiente",
        "inetto",
        "inettitudine",
        "disuguaglianza",
        "iniquo",
        "inerte",
        "imperdonabile",
        "inesperienza",
        "inesperto",
        "inspiegabile",
        "famigerato",
        "infamia",
        "infanticidio",
        "infantile",
        "infarto",
        "infettare",
        "infezione",
        "contagioso",
        "inferiore",
        "inferiorità",
        "inferno",
        "infertilità",
        "infestazione",
        "infedele",
        "infedeltà",
        "infermo",
        "infermità",
        "infiammazione",
        "gonfiato",
        "inflazione",
        "infliggere",
        "inflizione",
        "influenza",
        "informatore",
        "infrazione",
        "non frequentemente",
        "violazione",
        "inibire",
        "inospitale",
        "disumano",
        "disumanità",
        "nemico",
        "iniquità",
        "ingiunzione",
        "ferire",
        "ferito",
        "dannoso",
        "lesione",
        "ingiustizia",
        "detenuto",
        "non operativo",
        "pazzo",
        "follia",
        "insicuro",
        "insicurezza",
        "insidioso",
        "insignificanza",
        "insignificante",
        "insipido",
        "insolente",
        "insolvenza",
        "insolvente",
        "instabilità",
        "istigare",
        "istigazione",
        "insufficienza",
        "insufficiente",
        "insufficientemente",
        "insulto",
        "offensivo",
        "ribelle",
        "insormontabile",
        "insurrezione",
        "Inter",
        "interdizione",
        "interferenza",
        "sepoltura",
        "interrompere",
        "interrotto",
        "intestato",
        "intimidire",
        "intimidazione",
        "intollerabile",
        "intolleranza",
        "intollerante",
        "intossicato",
        "intrattabile",
        "intrigo",
        "intruso",
        "intrusione",
        "invadente",
        "invadere",
        "invasore",
        "invalidare",
        "invalidamento",
        "invalidità",
        "invasione",
        "involontario",
        "involuzione",
        "irato",
        "ira",
        "ferri da stiro",
        "irrazionale",
        "irrazionalità",
        "inconciliabile",
        "irregolare",
        "irregolarità",
        "irrilevante",
        "irreparabile",
        "irresponsabile",
        "irriverente",
        "irrevocabile",
        "irritabilità",
        "irritabile",
        "irritante",
        "irritazione",
        "isolato",
        "isolamento",
        "blaterare",
        "prigione",
        "gergo",
        "stridente",
        "ittero",
        "geloso",
        "gelosia",
        "mettere a repentaglio",
        "pericolo",
        "John",
        "scherzo",
        "giornada",
        "miscuglio",
        "Rifiuto",
        "giunta",
        "giovanile",
        "creno",
        "calcio",
        "rapire",
        "uccisione",
        "uccidere",
        "aquilone",
        "rintocco",
        "annodato",
        "ha lavorato",
        "laborioso",
        "labirinto",
        "la mancanza",
        "carente",
        "poco brillante",
        "carico",
        "ritardo",
        "in ritardo",
        "tana",
        "lamento",
        "frana",
        "languido",
        "languire",
        "languire",
        "periodo",
        "furto",
        "frusta",
        "tardi",
        "ritardo",
        "latente",
        "latrine",
        "risibile",
        "lava",
        "illegalità",
        "causa",
        "avvocato",
        "lassista",
        "lassativo",
        "pigro",
        "perdere",
        "perdita",
        "che perde",
        "partire",
        "sanguisuga",
        "sanguisughe",
        "leer",
        "Limone",
        "lebbra",
        "lesbica",
        "diminuire",
        "minore",
        "letale",
        "letargia",
        "leucemia",
        "prelievo",
        "osceno",
        "collegamento",
        "bugiardo",
        "diffamazione",
        "leccata",
        "menzogna",
        "senza vita",
        "limitato",
        "zoppicare",
        "pelucchi",
        "liquore",
        "svogliato",
        "litigioso",
        "litigare",
        "contenzioso",
        "contenzioso",
        "rifiuti",
        "livido",
        "pagnotta",
        "mocassino",
        "restio",
        "detestare",
        "disgusto",
        "ripugnante",
        "lobbista",
        "blocco",
        "locusta",
        "elevato",
        "solitudine",
        "solitario",
        "solitario",
        "gabinetto",
        "telaio",
        "lunatico",
        "pazzo",
        "bottino",
        "perdere",
        "perdere",
        "perdita",
        "perduto",
        "volume",
        "sala",
        "pidocchio",
        "minore",
        "abbassamento",
        "più basso",
        "pianure",
        "umile",
        "ridicolo",
        "ingombrante",
        "massa",
        "grumoso",
        "follia",
        "pazzo",
        "barcollare",
        "adescare",
        "lurido",
        "in agguato",
        "in agguato",
        "lussureggiante",
        "lussuria",
        "lussurioso",
        "dire bugie",
        "linciare",
        "Mazza",
        "pazzo",
        "impazzire",
        "pazzo",
        "follia",
        "mafia",
        "verme",
        "improvvisato",
        "malattia",
        "malessere",
        "malaria",
        "malevolo",
        "illecito",
        "malformazione",
        "malizia",
        "dannoso",
        "maligno",
        "malignità",
        "maligno",
        "negligenza",
        "mandamus",
        "rogna",
        "mazza",
        "mania",
        "maniaco",
        "maniacale",
        "manipolare",
        "manipolazione",
        "omicidio colposo",
        "letame",
        "mar",
        "margine",
        "marrone",
        "martingala",
        "martire",
        "martirio",
        "masochismo",
        "massacro",
        "materialismo",
        "materialista",
        "tortuoso",
        "senza senso",
        "morbillo",
        "intromettersi",
        "mediocre",
        "mediocrità",
        "malinconico",
        "malinconia",
        "mischia",
        "melodramma",
        "fusione",
        "minaccia",
        "minaccioso",
        "umile",
        "mercenario",
        "spietato",
        "disordine",
        "disordinato",
        "metastasi",
        "metanolo",
        "muffa",
        "milizia",
        "mimica",
        "minimizzare",
        "minimo",
        "minoranza",
        "fango",
        "comportamento scorretto",
        "cattiva amministrazione",
        "dispetto",
        "malizioso",
        "equivoco",
        "cattiva condotta",
        "miserabile",
        "miserabilmente",
        "miseria",
        "disgrazia",
        "fuorviato",
        "disavventura",
        "incomprensioni",
        "indurre in errore",
        "ingannevole",
        "cattiva gestione",
        "mancata corrispondenza",
        "termine improprio",
        "posto sbagliato",
        "fuori luogo",
        "travisare",
        "falsa dichiarazione",
        "travisato",
        "mancante",
        "errore",
        "errore",
        "sbagliato",
        "padrona",
        "diffidare",
        "fraintendere",
        "malinteso",
        "uso improprio",
        "acaro",
        "assalire",
        "presa in giro",
        "beffardo",
        "molestie",
        "monocromo",
        "monopolista",
        "monsone",
        "mostro",
        "mostruosità",
        "lunatico",
        "discutibile",
        "morboso",
        "morbilità",
        "obitorio",
        "moribondo",
        "ritardato mentale",
        "idiota",
        "boccone",
        "mortale",
        "mortalità",
        "mortificazione",
        "camera mortuaria",
        "zanzara",
        "essere in lutto",
        "triste",
        "lutto",
        "fango",
        "fango",
        "confondere",
        "confuso",
        "fangoso",
        "manicotto",
        "mulo",
        "mamma",
        "borbottare",
        "parotite",
        "omicidio",
        "assassino",
        "omicida",
        "oscuro",
        "muschio",
        "ammuffito",
        "mutante",
        "mutilato",
        "mutilazione",
        "ammutinamento",
        "borbottare",
        "museruola",
        "miopia",
        "becca",
        "nadir",
        "brontolare",
        "ingenuo",
        "senza nome",
        "pannolino",
        "narcotico",
        "sgradevole",
        "cattivo",
        "nausea",
        "nauseante",
        "anzi",
        "necessario",
        "bisognoso",
        "nefasto",
        "negazione",
        "negativo",
        "trascurare",
        "trascurato",
        "trascurare",
        "negligenza",
        "negligente",
        "negligentemente",
        "negro",
        "nepotismo",
        "nervoso",
        "nether",
        "ortica",
        "nevralgia",
        "nevrosi",
        "nevrotico",
        "nicotina",
        "negro",
        "incubo",
        "nichilismo",
        "rumore",
        "rumoroso",
        "non conformità",
        "senza senso",
        "senza senso",
        "cappio",
        "nulla",
        "nocivo",
        "fastidio",
        "nullo",
        "annullare",
        "intorpidire",
        "intorpidimento",
        "suora",
        "idiota",
        "obeso",
        "obesità",
        "obi",
        "necrologio",
        "necrologio",
        "obiezione",
        "discutibile",
        "obbligare",
        "debitore",
        "cancellare",
        "cancellato",
        "obliterazione",
        "oblio",
        "odioso",
        "osceno",
        "oscenità",
        "oscurità",
        "ostacolo",
        "ostinato",
        "ostacolare",
        "ostruzione",
        "ostruttivo",
        "ottuso",
        "occulto",
        "stranezza",
        "odioso",
        "odore",
        "offendere",
        "offeso",
        "delinquente",
        "offesa",
        "offensivo",
        "disinvolto",
        "offendo",
        "orco",
        "olfattivo",
        "oligarchia",
        "presagio",
        "infausto",
        "omettere",
        "oneroso",
        "onere",
        "trasudare",
        "opaco",
        "operistico",
        "oppiacei",
        "supponente",
        "oppio",
        "avversario",
        "opporsi",
        "contrario",
        "opposizione",
        "opprimere",
        "oppressione",
        "oppressivo",
        "oppressore",
        "orco",
        "calvario",
        "ordigni",
        "orfano",
        "apparentemente",
        "cacciare",
        "emarginato",
        "grido",
        "dipendenza",
        "stravagante",
        "fuorilegge",
        "indignazione",
        "ovazione",
        "prepotente",
        "sovraccaricare",
        "nuvoloso",
        "esagerare",
        "overdose",
        "in ritardo",
        "sopravvalutato",
        "traboccare",
        "invaso",
        "sovraccarico",
        "pagato in eccesso",
        "sopraffare",
        "prepotente",
        "caro",
        "supervisione",
        "rovesciare",
        "capovolgere",
        "sopraffare",
        "sopraffatto",
        "dovuto",
        "ossidazione",
        "dolore",
        "addolorato",
        "doloroso",
        "dolorosamente",
        "dolori",
        "paralisi",
        "pandemia",
        "spasimo",
        "panico",
        "paralisi",
        "paralizzato",
        "paranoia",
        "parassita",
        "pare",
        "pappagallo",
        "parsimonioso",
        "partigiano",
        "passare",
        "passivo",
        "passività",
        "toppa",
        "patetico",
        "paternalistico",
        "picchiettio",
        "scarsità",
        "povero",
        "pedone",
        "restituire",
        "pagamento",
        "particolarità",
        "pedone",
        "penale",
        "pena",
        "penetrazione",
        "penitenziario",
        "perdizione",
        "pericolo",
        "pericoloso",
        "perire",
        "deperibile",
        "perì",
        "perire",
        "spergiuro",
        "pernicioso",
        "autore",
        "perpetuazione",
        "perplesso",
        "perplessità",
        "perseguitare",
        "persecuzione",
        "perturbazione",
        "pertosse",
        "perverso",
        "perversione",
        "pervertito",
        "pervertito",
        "pessimismo",
        "pessimista",
        "peste",
        "pestilenza",
        "animale domestico",
        "trascurabile",
        "fantasma",
        "catarro",
        "falso",
        "picchetto",
        "picchettaggio",
        "salamoia",
        "maiale",
        "piccione",
        "pile",
        "saccheggio",
        "magnaccia",
        "brufolo",
        "pino",
        "pignone",
        "pizzicare",
        "pirateria",
        "pirata",
        "pistola",
        "trappola",
        "plagio",
        "appestare",
        "querelante",
        "placcato",
        "giocatore",
        "implorazione",
        "situazione",
        "arrancando",
        "precipitare",
        "saccheggiare",
        "tuffo",
        "polmonite",
        "bracconaggio",
        "inutile",
        "veleno",
        "avvelenato",
        "avvelenamento",
        "velenoso",
        "colpire",
        "polemica",
        "polio",
        "inquinare",
        "inquinamento",
        "poligamia",
        "pompa",
        "pomposo",
        "ponderoso",
        "male",
        "pop",
        "porcospino",
        "porno",
        "porno",
        "pornografico",
        "pornografia",
        "posa",
        "posseduto",
        "possesso",
        "postumo",
        "rinvio",
        "libbra",
        "povertà",
        "impotente",
        "scherzo",
        "precario",
        "recinto",
        "predatore",
        "predica",
        "gravidanza",
        "pregiudizio",
        "prevenuto",
        "pregiudizievole",
        "premeditato",
        "pressione",
        "presuntuoso",
        "far finta",
        "finse",
        "fingendo",
        "finzione",
        "pretese",
        "preventivo",
        "preda",
        "puntura",
        "spinoso",
        "prigione",
        "prigioniero",
        "privato",
        "problema",
        "procrastinare",
        "indugio",
        "profano",
        "volgarità",
        "profusione",
        "proibito",
        "divieto",
        "prolungare",
        "promiscuo",
        "propaganda",
        "perseguire",
        "accusa",
        "prostituta",
        "prostituzione",
        "provocazione",
        "provocante",
        "fare leva",
        "indiscreto",
        "psicosi",
        "pubblicista",
        "gonfio",
        "punch",
        "pungente",
        "punire",
        "punito",
        "punire",
        "punizione",
        "punitivo",
        "purgatorio",
        "epurazione",
        "pus",
        "ciarlatano",
        "pantano",
        "Quaglia",
        "dilemma",
        "litigare",
        "schiacciare",
        "reprimere",
        "discutibile",
        "argento vivo",
        "uscire",
        "faretra",
        "tremante",
        "quiz",
        "marmaglia",
        "rabbioso",
        "rabbia",
        "cremagliera",
        "racchetta",
        "radiazione",
        "radioattivo",
        "radon",
        "rabbia",
        "furioso",
        "stracci",
        "incursione",
        "rotaia",
        "ariete",
        "sconclusionato",
        "furia",
        "rancido",
        "riscatto",
        "stupro",
        "rapaci",
        "mascalzone",
        "eruzione cutanea",
        "ratto",
        "valutazione",
        "rauco",
        "famelico",
        "delirio",
        "reazionario",
        "parte posteriore",
        "ribelle",
        "rimprovero",
        "confutare",
        "recalcitrante",
        "recessione",
        "recidiva",
        "spericolato",
        "incoscienza",
        "ridondante",
        "riflusso",
        "refrattario",
        "rifiuto",
        "rifiutare",
        "rifiutato",
        "regredire",
        "regressione",
        "rimpiangere",
        "deplorevole",
        "dispiaciuto",
        "rimpiangere",
        "regolamentare",
        "redini",
        "rifiutare",
        "respinto",
        "rifiuto",
        "rifiuta",
        "ricaduta",
        "retrocessione",
        "rinunciare",
        "riluttante",
        "custodia cautelare",
        "riparatore",
        "negligente",
        "rimorso",
        "rimozione",
        "rimuovere",
        "rincontrare",
        "strappare",
        "rinnegato",
        "rinunciare",
        "rinuncia",
        "repellente",
        "repellente",
        "respingendo",
        "reprimere",
        "repressione",
        "rimproverare",
        "ristampare",
        "rappresaglia",
        "rimprovero",
        "repubblica",
        "ripudio",
        "repulsione",
        "rescindere",
        "rescissione",
        "risentirsi di",
        "risentito",
        "risentimento",
        "dimettersi",
        "dimissioni",
        "rassegnato",
        "resistere",
        "resistenza",
        "resistente",
        "resistere",
        "frenare",
        "limitare",
        "restrizione",
        "restrittivo",
        "vendicarsi",
        "ritorsione",
        "ritorsione",
        "ritardare",
        "ritardo",
        "reticente",
        "storta",
        "ritrattare",
        "retrazione",
        "ridimensionamento",
        "retribuzione",
        "retrogrado",
        "vendetta",
        "inversione",
        "revoca",
        "revocare",
        "rivolta",
        "rivoltante",
        "revolver",
        "repulsione",
        "reumatismi",
        "traballante",
        "crivellato",
        "ridicolo",
        "ridicolo",
        "abbondante",
        "fucile",
        "spaccatura",
        "rigido",
        "rigidità",
        "rigore",
        "rigoroso",
        "suoneria",
        "rivolta",
        "ribelle",
        "rischio",
        "rischioso",
        "rivalità",
        "rapinare",
        "ladro",
        "rapina",
        "briccone",
        "torre",
        "marcire",
        "in decomposizione",
        "rugosità",
        "rotta",
        "riga",
        "chiassoso",
        "sciocchezze",
        "macerie",
        "ruta",
        "balza",
        "robusto",
        "rovina",
        "rovinato",
        "rovinoso",
        "pettegolezzo",
        "fuggire",
        "rottura",
        "stratagemma",
        "ruggine",
        "arrugginito",
        "spietato",
        "sciabola",
        "sabotaggio",
        "sacrifici",
        "purtroppo",
        "tristezza",
        "afflosciarsi",
        "linfa",
        "sarcasmo",
        "sarcoma",
        "sardonico",
        "satanico",
        "saturato",
        "attaccare",
        "ferocia",
        "crosta",
        "impalcatura",
        "bisturi",
        "squamoso",
        "scandalo",
        "scandaloso",
        "scarso",
        "capro espiatorio",
        "cicatrice",
        "scarso",
        "appena",
        "scarsità",
        "spavento",
        "spazzino",
        "schema",
        "scisma",
        "schizofrenia",
        "sciatica",
        "deridere",
        "rimproverare",
        "rimproverare",
        "rovente",
        "disprezzo",
        "scorpione",
        "scotch",
        "mascalzone",
        "flagellare",
        "rimescolando",
        "scrapie",
        "grido",
        "urlando",
        "strillare",
        "avvitato",
        "mischia",
        "macchia",
        "scrutare",
        "scrutinio",
        "feccia",
        "scottare",
        "secessione",
        "appartato",
        "Seconda mano",
        "secrezione",
        "segreto",
        "settario",
        "sedizione",
        "sedurre",
        "seduzione",
        "segregare",
        "segregato",
        "prendere",
        "egoista",
        "egoismo",
        "senile",
        "insensato",
        "frase",
        "separatista",
        "sepsi",
        "settico",
        "sequestro",
        "sereno",
        "serpente",
        "servo",
        "servire",
        "servile",
        "servitù",
        "battuta d'arresto",
        "sever",
        "liquame",
        "fognatura",
        "squallido",
        "baracca",
        "grillo",
        "ombreggiato",
        "tremante",
        "traballante",
        "farsa",
        "macello",
        "vergogna",
        "vergognoso",
        "senza vergogna",
        "shanghai",
        "squalo",
        "frantumare",
        "in frantumi",
        "capannone",
        "guscio",
        "accantonato",
        "naufragio",
        "merda",
        "brivido",
        "shock",
        "scadente",
        "sparare",
        "tiro",
        "taccheggio",
        "carenza",
        "discordanza",
        "sparo",
        "spingere",
        "appariscente",
        "strillare",
        "stridulo",
        "restringersi",
        "rimpicciolito",
        "brivido",
        "evita",
        "malato",
        "nauseante",
        "malaticcio",
        "malattia",
        "sciocco",
        "peccato",
        "peccaminoso",
        "sinistro",
        "peccatore",
        "peccare",
        "sirena",
        "femminuccia",
        "scettico",
        "abbozzato",
        "obliquo",
        "slittata",
        "Salta",
        "scaramuccia",
        "lento",
        "scorie",
        "sbattere",
        "calunnia",
        "calunnioso",
        "schiaffo",
        "macellare",
        "macello",
        "macellazione",
        "schiavo",
        "schiavitù",
        "uccidere",
        "assassino",
        "nevischio",
        "viscido",
        "sgattaiolare",
        "scontrino",
        "scia",
        "troppo liquido",
        "pigrizia",
        "sciatto",
        "pantano",
        "lentezza",
        "fango",
        "lumaca",
        "lento",
        "slum",
        "crollo",
        "legatura",
        "fanghiglia",
        "troia",
        "furbo",
        "schiaffo",
        "piccolo",
        "distruggere",
        "fracassato",
        "infarinante",
        "odore",
        "odoroso",
        "sorrisetto",
        "punire",
        "fumatore",
        "soffocare",
        "macchia",
        "compiaciuto",
        "contrabbandare",
        "contrabbandiere",
        "contrabbando",
        "sudiciume",
        "intoppo",
        "intoppi",
        "serpente",
        "trappola",
        "ringhio",
        "ringhiando",
        "sgattaiolare",
        "furtivamente",
        "sogghignare",
        "starnuto",
        "beffardo",
        "snob",
        "bagnare",
        "singhiozzare",
        "socialista",
        "suolo",
        "sporco",
        "somatico",
        "cupo",
        "fuliggine",
        "stregoneria",
        "sordido",
        "irritato",
        "dolorosamente",
        "dolore",
        "tristezza",
        "doloroso",
        "sortita",
        "senz'anima",
        "anima gemella",
        "acido",
        "sculacciare",
        "spasmo",
        "sputare",
        "lancia",
        "speck",
        "spettro",
        "spettrale",
        "speculazione",
        "speso",
        "zitella",
        "dispetto",
        "dispettoso",
        "scheggia",
        "diviso",
        "scissione",
        "rovinare",
        "spoiler",
        "ha parlato",
        "spugna",
        "spaventare",
        "distorsione",
        "baldoria",
        "sprite",
        "spurio",
        "burrasca",
        "squatter",
        "schizzinoso",
        "strillare",
        "contorcersi",
        "pugnalare",
        "sbalorditivo",
        "stagnante",
        "macchia",
        "stantio",
        "gambo",
        "stallo",
        "fermo",
        "fissando",
        "rigido",
        "sussultare",
        "fame",
        "affamato",
        "affamato",
        "stazionario",
        "doga",
        "rubare",
        "rubare",
        "furtivo",
        "stereotipo",
        "stereotipato",
        "sterile",
        "sterilità",
        "poppa",
        "rigido",
        "rigidità",
        "soffocare",
        "soffocato",
        "stigma",
        "nato morto",
        "puntura",
        "pungente",
        "avaro",
        "puzza",
        "puzzolente",
        "periodo",
        "scorte",
        "rubato",
        "calcolo",
        "sballato",
        "sgabelli",
        "arresto",
        "tempesta",
        "tempestoso",
        "teso",
        "stretto",
        "incagliato",
        "sconosciuto",
        "strangolare",
        "randagio",
        "fatica",
        "conflitto",
        "colpire",
        "striscia",
        "banda",
        "spogliato",
        "ictus",
        "lotta",
        "pavoneggiarsi",
        "soffocante",
        "inciampare",
        "stordito",
        "rachitico",
        "stupido",
        "stupidità",
        "stupore",
        "porcile",
        "sottomettere",
        "materia",
        "sottoposto",
        "soggezione",
        "soggiogazione",
        "subordinare",
        "citazione",
        "cedimento",
        "sussidio",
        "sussistere",
        "sottrarre",
        "sovversione",
        "sovversivo",
        "sovvertire",
        "soccombere",
        "succhiare",
        "ventosa",
        "citare in giudizio",
        "soffrire",
        "malato",
        "sofferenza",
        "soffocante",
        "soffocamento",
        "suicida",
        "suicidio",
        "imbronciato",
        "convocazione",
        "affondato",
        "superficiale",
        "superfluo",
        "superstizioso",
        "sopprimere",
        "soppressione",
        "sovraccarico",
        "scontroso",
        "arrendersi",
        "arrendendosi",
        "suscettibile",
        "sospettare",
        "sospensione",
        "sospetto",
        "sospettoso",
        "tampone",
        "pantano",
        "paludoso",
        "svastica",
        "rigonfiamento",
        "sorso",
        "suino",
        "gonfio",
        "sintomo",
        "sincope",
        "tabù",
        "macchia",
        "artigli",
        "aggrovigliato",
        "ritardo",
        "tardivo",
        "tariffa",
        "appannare",
        "aspetta",
        "insapore",
        "scherno",
        "imposta",
        "burlone",
        "dispettoso",
        "noioso",
        "tedio",
        "tempesta",
        "tentazione",
        "caseggiato",
        "terminale",
        "cessazione",
        "termite",
        "terribile",
        "terrore",
        "terrorismo",
        "terrorista",
        "terrorizzare",
        "tetano",
        "legare",
        "furto",
        "teismo",
        "teocratico",
        "ladro",
        "assetato",
        "spina",
        "spinoso",
        "senza pensieri",
        "picchiare",
        "minaccia",
        "minacciare",
        "minaccioso",
        "trebbiare",
        "pulsare",
        "acceleratore",
        "delinquente",
        "tonfo",
        "tuonante",
        "contrastare",
        "tiff",
        "timido",
        "timidezza",
        "brillo",
        "tirata",
        "stanco",
        "stanchezza",
        "noioso",
        "tit",
        "rospo",
        "tabacco",
        "gabinetto",
        "fatiche",
        "tollerare",
        "mal di denti",
        "tormento",
        "strappato",
        "siluro",
        "torrido",
        "torto",
        "tortuoso",
        "tortura",
        "toccato",
        "permaloso",
        "difficile",
        "tossico",
        "tossina",
        "tragedia",
        "tragico",
        "traditore",
        "vagabondo",
        "trance",
        "trasgressione",
        "orpelli",
        "trappole",
        "spazzatura",
        "scadente",
        "traumatico",
        "travaglio",
        "travestimento",
        "infido",
        "tradimento",
        "tradimento",
        "tremito",
        "tremore",
        "trepidazione",
        "trasgredire",
        "tribolazione",
        "tribunale",
        "trucco",
        "inganno",
        "tartufo",
        "inciampare",
        "troll",
        "fastidioso",
        "tromba",
        "cadere",
        "tumore",
        "tumore",
        "tumulto",
        "tumultuoso",
        "turbolenza",
        "turbolento",
        "tumulto",
        "contrazione",
        "tifone",
        "tirannico",
        "tirannia",
        "tiranno",
        "bruttezza",
        "brutta",
        "ulcera",
        "ulteriore",
        "ultimatum",
        "incapace",
        "inaccettabile",
        "irresponsabile",
        "non approvato",
        "distaccato",
        "irraggiungibile",
        "poco attraente",
        "non autorizzato",
        "inevitabile",
        "inconsapevole",
        "insopportabile",
        "incredulità",
        "incredibile",
        "non nato",
        "misterioso",
        "indifferente",
        "incerto",
        "immutabile",
        "impuro",
        "scomodo",
        "inconcepibile",
        "inconscio",
        "incostituzionale",
        "incontrollabile",
        "incontrollato",
        "indeciso",
        "minato",
        "sottopagato",
        "sottodimensionato",
        "indesiderabile",
        "indesiderato",
        "annullare",
        "disagio",
        "a disagio",
        "ignorante",
        "disoccupato",
        "disuguale",
        "irregolare",
        "non spiegato",
        "sleale",
        "ingiustizia",
        "infedele",
        "sfavorevole",
        "incompiuto",
        "intransigente",
        "sfortunato",
        "ostile",
        "insoddisfatto",
        "non ammobiliato",
        "empio",
        "ingrato",
        "infelicità",
        "infelice",
        "malsano",
        "empio",
        "irrilevante",
        "indifferente",
        "non migliorato",
        "disinformato",
        "non iniziato",
        "non ispirato",
        "incomprensibile",
        "involontariamente",
        "disinteressato",
        "non interessante",
        "ingiusto",
        "ingiustificabile",
        "ingiustificato",
        "scortese",
        "sconosciuto",
        "illegale",
        "senza licenza",
        "sfortunato",
        "ingestibile",
        "innaturale",
        "non ufficiale",
        "non pagato",
        "sgradevole",
        "impopolare",
        "imprevedibile",
        "impreparato",
        "improduttivo",
        "non redditizio",
        "non protetto",
        "inedito",
        "inaffidabile",
        "non corrisposto",
        "indisciplinato",
        "pericoloso",
        "insoddisfacente",
        "insoddisfatto",
        "sgradevole",
        "senza scrupoli",
        "instabile",
        "sgradevole",
        "non sofisticato",
        "indicibile",
        "instabile",
        "senza esito",
        "inadatto",
        "non celebrato",
        "non supportato",
        "insostenibile",
        "antipatico",
        "selvaggio",
        "insostenibile",
        "impensabile",
        "disordinato",
        "prematura",
        "Senza titolo",
        "non detto",
        "sfavorevole",
        "non addestrato",
        "falso",
        "inaffidabile",
        "ingiustificato",
        "non lavato",
        "sgradito",
        "male",
        "riluttanza",
        "poco saggio",
        "inconsapevole",
        "indegno",
        "inflessibile",
        "sconvolgimento",
        "rivolta",
        "tumulto",
        "rovesciato",
        "monello",
        "urgente",
        "inutile",
        "usurpare",
        "usurpato",
        "usura",
        "posto vacante",
        "vacuo",
        "vago",
        "vaghezza",
        "invano",
        "vampiro",
        "svanito",
        "vanità",
        "varicella",
        "varicoso",
        "vegetativo",
        "veemente",
        "vendetta",
        "vendetta",
        "vendicativo",
        "veleno",
        "velenoso",
        "verbosità",
        "limite",
        "parassiti",
        "contro",
        "vertigine",
        "veto",
        "vice",
        "vizioso",
        "vittima",
        "vittimizzato",
        "furfante",
        "malvagio",
        "vendicativo",
        "violazione",
        "violenza",
        "violento",
        "violentemente",
        "vipera",
        "virulenza",
        "virus",
        "visita",
        "volpe",
        "volatilità",
        "vulcano",
        "vomito",
        "vudù",
        "volgare",
        "volgarità",
        "vulnerabilità",
        "avvoltoio",
        "cialda",
        "gemere",
        "aspettare",
        "sguazzare",
        "pallido",
        "svanire",
        "volere",
        "guerra",
        "guardiano",
        "merce",
        "guerra",
        "bellicoso",
        "avvisare",
        "ordito",
        "deformato",
        "verruca",
        "sciupare",
        "sprecato",
        "dispendioso",
        "sprecare",
        "acquoso",
        "vacillare",
        "indebolito",
        "debolmente",
        "debolezza",
        "indossare",
        "stancamente",
        "stanchezza",
        "stanco",
        "erbacce",
        "pianto",
        "strano",
        "strano",
        "ven",
        "fanciulla",
        "colpisci",
        "capriccio",
        "gemito",
        "frusta",
        "vortice",
        "Whisky",
        "puttana",
        "malvagio",
        "malvagità",
        "selvaggio",
        "gatto selvatico",
        "macchia d'olio",
        "volontario",
        "sfigato",
        "debole",
        "sussultare",
        "strega",
        "stregoneria",
        "ritirare",
        "appassire",
        "appassito",
        "guai",
        "doloroso",
        "tristemente",
        "parole",
        "verme",
        "logoro",
        "preoccupato",
        "preoccupazione",
        "preoccupante",
        "peggio",
        "peggioramento",
        "inutile",
        "ferita",
        "litigare",
        "collera",
        "devastare",
        "relitto",
        "distrutto",
        "chiave inglese",
        "lotta",
        "miserabile",
        "miserabile",
        "sbagliato",
        "trasgressione",
        "ingiusto",
        "erroneamente",
        "battuto",
        "ironico",
        "xenofobia",
        "sbadiglio",
        "sbadigliando",
        "urlo",
        "gialli",
        "guaire",
        "cerniera lampo",
    ]
)

_ambivalent = set(
    [
        "abbondanza",
        "armato",
        "balsamo",
        "vantarsi",
        "chiassoso",
        "topo di biblioteca",
        "secchio",
        "celebrità",
        "Ammaliato",
        "elusione",
        "complicità",
        "confessare",
        "astuzia",
        "dipendente",
        "diverso",
        "dominare",
        "infinito",
        "imporre",
        "erotico",
        "fuga",
        "sensazione",
        "flirtare",
        "salve",
        "edonismo",
        "più alto",
        "umile",
        "subito",
        "immobile",
        "reddito",
        "infiltrazione",
        "influenza",
        "intenso",
        "interminabile",
        "intervento",
        "pizzo",
        "liberale",
        "signore",
        "materno",
        "ostetrica",
        "madre",
        "tazza",
        "notorietà",
        "onnipotenza",
        "sfogo",
        "eccezionale",
        "parata",
        "parafrasi",
        "petrolio",
        "presentazione",
        "prodigo",
        "Citazione",
        "delirio",
        "regressivo",
        "riaccendere",
        "resti",
        "la pensione",
        "rinascere",
        "rivoluzione",
        "spaventapasseri",
        "isolamento",
        "sensuale",
        "spettacolo",
        "colonna vertebrale",
        "sterlina",
        "succulento",
        "superstizione",
        "supremazia",
        "circondare",
        "sinonimo",
        "allettante",
        "adolescenti",
        "trattare",
        "imbattuto",
        "sfrenato",
        "inaspettato",
        "inimmaginabile",
        "sciogliere",
        "salita",
        "votazione",
        "il peso",
        "brama",
    ]
)
